@@ -21,9 +21,8 @@ import logging
 import warnings
 
 from abc import ABC
-from typing import List, Sequence, Tuple, cast
+from typing import Dict, List, Optional, Sequence, Set, Tuple, Union, cast
 
-import aesara.tensor as at
 import numpy as np
 
 from pymc.backends.report import SamplerReport
@@ -61,6 +60,9 @@ class BaseTrace(ABC):
         if vars is None:
             vars = model.unobserved_value_vars
 
+        unnamed_vars = {var for var in vars if var.name is None}
+        if unnamed_vars:
+            raise Exception(f"Can't trace unnamed variables: {unnamed_vars}")
         self.vars = vars
         self.varnames = [var.name for var in vars]
         self.fn = model.compile_fn(vars, inputs=model.value_vars, on_unused_input="ignore")
@@ -207,18 +209,18 @@ class BaseTrace(ABC):
         """Get sampler statistics."""
         raise NotImplementedError()
 
-    def _slice(self, idx):
+    def _slice(self, idx: Union[int, slice]):
         """Slice trace object."""
         raise NotImplementedError()
 
-    def point(self, idx):
+    def point(self, idx: int) -> Dict[str, np.ndarray]:
         """Return dictionary of point values at `idx` for current chain
         with variables names as keys.
         """
         raise NotImplementedError()
 
     @property
-    def stat_names(self):
+    def stat_names(self) -> Set[str]:
         names = set()
         for vars in self.sampler_vars or []:
             names.update(vars.keys())
@@ -277,12 +279,10 @@ class MultiTrace:
         List of variable names in the trace(s)
     """
 
-    def __init__(self, straces):
-        self._straces = {}
-        for strace in straces:
-            if strace.chain in self._straces:
-                raise ValueError("Chains are not unique.")
-            self._straces[strace.chain] = strace
+    def __init__(self, straces: Sequence[BaseTrace]):
+        if len({t.chain for t in straces}) != len(straces):
+            raise ValueError("Chains are not unique.")
+        self._straces = {t.chain: t for t in straces}
 
         self._report = SamplerReport()
 
@@ -291,15 +291,15 @@ class MultiTrace:
         return template.format(self.__class__.__name__, self.nchains, len(self), len(self.varnames))
 
     @property
-    def nchains(self):
+    def nchains(self) -> int:
         return len(self._straces)
 
     @property
-    def chains(self):
+    def chains(self) -> List[int]:
         return list(sorted(self._straces.keys()))
 
     @property
-    def report(self):
+    def report(self) -> SamplerReport:
         return self._report
 
     def __iter__(self):
@@ -329,7 +329,7 @@ class MultiTrace:
         if var in self.varnames:
             if var in self.stat_names:
                 warnings.warn(
-                    "Attribute access on a trace object is ambigous. "
+                    "Attribute access on a trace object is ambiguous. "
                     "Sampler statistic and model variable share a name. Use "
                     "trace.get_values or trace.get_sampler_stats."
                 )
@@ -350,7 +350,7 @@ class MultiTrace:
         if name in self.varnames:
             if name in self.stat_names:
                 warnings.warn(
-                    "Attribute access on a trace object is ambigous. "
+                    "Attribute access on a trace object is ambiguous. "
                     "Sampler statistic and model variable share a name. Use "
                     "trace.get_values or trace.get_sampler_stats."
                 )
@@ -364,12 +364,12 @@ class MultiTrace:
         return len(self._straces[chain])
 
     @property
-    def varnames(self):
+    def varnames(self) -> List[str]:
         chain = self.chains[-1]
         return self._straces[chain].varnames
 
     @property
-    def stat_names(self):
+    def stat_names(self) -> Set[str]:
         if not self._straces:
             return set()
         sampler_vars = [s.sampler_vars for s in self._straces.values()]
@@ -383,74 +383,15 @@ class MultiTrace:
                 names.update(vars.keys())
         return names
 
-    def add_values(self, vals, overwrite=False) -> None:
-        """Add variables to traces.
-
-        Parameters
-        ----------
-        vals: dict (str: array-like)
-             The keys should be the names of the new variables. The values are expected to be
-             array-like objects. For traces with more than one chain the length of each value
-             should match the number of total samples already in the trace `(chains * iterations)`,
-             otherwise a warning is raised.
-        overwrite: bool
-            If `False` (default) a ValueError is raised if the variable already exists.
-            Change to `True` to overwrite the values of variables
-
-        Returns
-        -------
-            None.
-        """
-        for k, v in vals.items():
-            new_var = 1
-            if k in self.varnames:
-                if overwrite:
-                    self.varnames.remove(k)
-                    new_var = 0
-                else:
-                    raise ValueError(f"Variable name {k} already exists.")
-
-            self.varnames.append(k)
-
-            chains = self._straces
-            l_samples = len(self) * len(self.chains)
-            l_v = len(v)
-            if l_v != l_samples:
-                warnings.warn(
-                    "The length of the values you are trying to "
-                    "add ({}) does not match the number ({}) of "
-                    "total samples in the trace "
-                    "(chains * iterations)".format(l_v, l_samples)
-                )
-
-            v = np.squeeze(v.reshape(len(chains), len(self), -1))
-
-            for idx, chain in enumerate(chains.values()):
-                if new_var:
-                    dummy = at.as_tensor_variable([], k)
-                    chain.vars.append(dummy)
-                chain.samples[k] = v[idx]
-
-    def remove_values(self, name):
-        """remove variables from traces.
-
-        Parameters
-        ----------
-        name: str
-            Name of the variable to remove. Raises KeyError if the variable is not present
-        """
-        varnames = self.varnames
-        if name not in varnames:
-            raise KeyError(f"Unknown variable {name}")
-        self.varnames.remove(name)
-        chains = self._straces
-        for chain in chains.values():
-            for va in chain.vars:
-                if va.name == name:
-                    chain.vars.remove(va)
-                    del chain.samples[name]
-
-    def get_values(self, varname, burn=0, thin=1, combine=True, chains=None, squeeze=True):
+    def get_values(
+        self,
+        varname: str,
+        burn: int = 0,
+        thin: int = 1,
+        combine: bool = True,
+        chains: Optional[Union[int, Sequence[int]]] = None,
+        squeeze: bool = True,
+    ) -> List[np.ndarray]:
         """Get values from traces.
 
         Parameters
@@ -476,13 +417,20 @@ class MultiTrace:
         if chains is None:
             chains = self.chains
         varname = get_var_name(varname)
-        try:
-            results = [self._straces[chain].get_values(varname, burn, thin) for chain in chains]
-        except TypeError:  # Single chain passed.
-            results = [self._straces[chains].get_values(varname, burn, thin)]
+        if isinstance(chains, int):
+            chains = [chains]
+        results = [self._straces[chain].get_values(varname, burn, thin) for chain in chains]
         return _squeeze_cat(results, combine, squeeze)
 
-    def get_sampler_stats(self, stat_name, burn=0, thin=1, combine=True, chains=None, squeeze=True):
+    def get_sampler_stats(
+        self,
+        stat_name: str,
+        burn: int = 0,
+        thin: int = 1,
+        combine: bool = True,
+        chains: Optional[Union[int, Sequence[int]]] = None,
+        squeeze: bool = True,
+    ):
         """Get sampler statistics from the trace.
 
         Parameters
@@ -505,9 +453,7 @@ class MultiTrace:
 
         if chains is None:
             chains = self.chains
-        try:
-            chains = iter(chains)
-        except TypeError:
+        if isinstance(chains, int):
             chains = [chains]
 
         results = [
@@ -523,7 +469,7 @@ class MultiTrace:
         trace._report = self._report._slice(*idxs)
         return trace
 
-    def point(self, idx, chain=None):
+    def point(self, idx: int, chain: Optional[int] = None) -> Dict[str, np.ndarray]:
         """Return a dictionary of point values at `idx`.
 
         Parameters
@@ -542,7 +488,7 @@ class MultiTrace:
         Parameters
         ----------
         chains: list of int or N
-            The chains whose points should be inlcuded in the iterator.  If
+            The chains whose points should be included in the iterator.  If
             chains is not given, include points from all chains.
         """
         if chains is None:
