@@ -15,7 +15,6 @@
 from pymc.distributions.logprob import (  # isort:skip
     logcdf,
     logp,
-    joint_logp,
 )
 
 from pymc.distributions.bound import Bound
@@ -77,6 +76,7 @@ from pymc.distributions.discrete import (
 )
 from pymc.distributions.distribution import (
     Continuous,
+    CustomDist,
     DensityDist,
     Discrete,
     Distribution,
@@ -155,6 +155,7 @@ __all__ = [
     "OrderedLogistic",
     "OrderedProbit",
     "DensityDist",
+    "CustomDist",
     "Distribution",
     "SymbolicRandomVariable",
     "Continuous",
@@ -198,7 +199,6 @@ __all__ = [
     "Censored",
     "CAR",
     "PolyaGamma",
-    "joint_logp",
     "logp",
     "logcdf",
 ]
