@@ -23,37 +23,47 @@ from typing import Callable, Optional, Sequence, Tuple, Union
 
 import numpy as np
 
-from aeppl.abstract import MeasurableVariable, _get_measurable_outputs
-from aeppl.logprob import _logcdf, _logprob
-from aeppl.rewriting import logprob_rewrites_db
-from aesara import tensor as at
-from aesara.compile.builders import OpFromGraph
-from aesara.graph import node_rewriter
-from aesara.graph.basic import Node, clone_replace
-from aesara.graph.rewriting.basic import in2out
-from aesara.graph.utils import MetaType
-from aesara.tensor.basic import as_tensor_variable
-from aesara.tensor.random.op import RandomVariable
-from aesara.tensor.random.type import RandomType
-from aesara.tensor.var import TensorVariable
+from pytensor import tensor as at
+from pytensor.compile.builders import OpFromGraph
+from pytensor.graph import node_rewriter
+from pytensor.graph.basic import Node, Variable
+from pytensor.graph.replace import clone_replace
+from pytensor.graph.rewriting.basic import in2out
+from pytensor.graph.utils import MetaType
+from pytensor.tensor.basic import as_tensor_variable
+from pytensor.tensor.random.op import RandomVariable
+from pytensor.tensor.random.type import RandomType
+from pytensor.tensor.random.utils import normalize_size_param
+from pytensor.tensor.var import TensorVariable
 from typing_extensions import TypeAlias
 
-from pymc.aesaraf import convert_observed_data
 from pymc.distributions.shape_utils import (
     Dims,
     Shape,
+    _change_dist_size,
     convert_dims,
     convert_shape,
     convert_size,
     find_size,
     shape_from_dims,
 )
+from pymc.exceptions import BlockModelAccessError
+from pymc.logprob.abstract import (
+    MeasurableVariable,
+    _get_measurable_outputs,
+    _icdf,
+    _logcdf,
+    _logprob,
+)
+from pymc.logprob.rewriting import logprob_rewrites_db
+from pymc.model import BlockModelAccess
 from pymc.printing import str_for_dist
+from pymc.pytensorf import collect_default_updates, convert_observed_data
 from pymc.util import UNSET, _add_future_warning_tag
 from pymc.vartypes import string_types
 
 __all__ = [
-    "DensityDistRV",
+    "CustomDist",
     "DensityDist",
     "Distribution",
     "Continuous",
@@ -130,6 +140,14 @@ class DistributionMeta(ABCMeta):
                     dist_params = dist_params[3:]
                     return class_logcdf(value, *dist_params)
 
+            class_icdf = clsdict.get("icdf")
+            if class_icdf:
+
+                @_icdf.register(rv_type)
+                def icdf(op, value, *dist_params, **kwargs):
+                    dist_params = dist_params[3:]
+                    return class_icdf(value, *dist_params)
+
             class_moment = clsdict.get("moment")
             if class_moment:
 
@@ -137,7 +155,7 @@ class DistributionMeta(ABCMeta):
                 def moment(op, rv, rng, size, dtype, *dist_params):
                     return class_moment(rv, size, *dist_params)
 
-            # Register the Aesara `RandomVariable` type as a subclass of this
+            # Register the PyTensor `RandomVariable` type as a subclass of this
             # `Distribution` type.
             new_cls.register(rv_type)
 
@@ -170,7 +188,7 @@ class SymbolicRandomVariable(OpFromGraph):
     (0 for scalar, 1 for vector, ...)
      """
 
-    inline_aeppl: bool = False
+    inline_logprob: bool = False
     """Specifies whether the logprob function is derived automatically by introspection
     of the inner graph.
 
@@ -190,7 +208,7 @@ class SymbolicRandomVariable(OpFromGraph):
 
         Returns a dictionary with the symbolic expressions required for correct updating
         of random state input variables repeated function evaluations. This is used by
-        `aesaraf.compile_pymc`.
+        `pytensorf.compile_pymc`.
         """
         return {}
 
@@ -243,7 +261,7 @@ class Distribution(metaclass=DistributionMeta):
         transform : optional
             See ``Model.register_rv``.
         **kwargs
-            Keyword arguments that will be forwarded to ``.dist()`` or the Aesara RV Op.
+            Keyword arguments that will be forwarded to ``.dist()`` or the PyTensor RV Op.
             Most prominently: ``shape`` for ``.dist()`` or ``dtype`` for the Op.
 
         Returns
@@ -327,7 +345,7 @@ class Distribution(metaclass=DistributionMeta):
         shape : int, tuple, Variable, optional
             A tuple of sizes for each dimension of the new RV.
         **kwargs
-            Keyword arguments that will be forwarded to the Aesara RV Op.
+            Keyword arguments that will be forwarded to the PyTensor RV Op.
             Most prominently: ``size`` or ``dtype``.
 
         Returns
@@ -340,7 +358,7 @@ class Distribution(metaclass=DistributionMeta):
             warnings.warn(
                 "The `.dist(testval=...)` argument is deprecated and has no effect. "
                 "Initial values for sampling/optimization can be specified with `initval` in a modelcontext. "
-                "For using Aesara's test value features, you must assign the `.tag.test_value` yourself.",
+                "For using PyTensor's test value features, you must assign the `.tag.test_value` yourself.",
                 FutureWarning,
                 stacklevel=2,
             )
@@ -375,13 +393,13 @@ class Distribution(metaclass=DistributionMeta):
         return rv_out
 
 
-# Let Aeppl know that the SymbolicRandomVariable has a logprob.
+# Let PyMC know that the SymbolicRandomVariable has a logprob.
 MeasurableVariable.register(SymbolicRandomVariable)
 
 
 @_get_measurable_outputs.register(SymbolicRandomVariable)
 def _get_measurable_outputs_symbolic_random_variable(op, node):
-    # This tells Aeppl that any non RandomType outputs are measurable
+    # This tells PyMC that any non RandomType outputs are measurable
 
     # Assume that if there is one default_output, that's the only one that is measurable
     # In the rare case this is not what one wants, a specialized _get_measuarable_outputs
@@ -396,11 +414,11 @@ def _get_measurable_outputs_symbolic_random_variable(op, node):
 @node_rewriter([SymbolicRandomVariable])
 def inline_symbolic_random_variable(fgraph, node):
     """
-    This optimization expands the internal graph of a SymbolicRV when obtaining logp
-    from Aeppl, if the flag `inline_aeppl` is True.
+    Optimization that expands the internal graph of a SymbolicRV when obtaining the logp
+    graph, if the flag `inline_logprob` is True.
     """
     op = node.op
-    if op.inline_aeppl:
+    if op.inline_logprob:
         return clone_replace(op.inner_outputs, {u: v for u, v in zip(op.inner_inputs, node.inputs)})
 
 
@@ -443,15 +461,15 @@ class Continuous(Distribution):
     """Base class for continuous distributions"""
 
 
-class DensityDistRV(RandomVariable):
+class CustomDistRV(RandomVariable):
     """
-    Base class for DensityDistRV
+    Base class for CustomDistRV
 
-    This should be subclassed when defining custom DensityDist objects.
+    This should be subclassed when defining CustomDist objects.
     """
 
-    name = "DensityDistRV"
-    _print_name = ("DensityDist", "\\operatorname{DensityDist}")
+    name = "CustomDistRV"
+    _print_name = ("CustomDist", "\\operatorname{CustomDist}")
 
     @classmethod
     def rng_fn(cls, rng, *args):
@@ -460,132 +478,10 @@ class DensityDistRV(RandomVariable):
         return cls._random_fn(*args, rng=rng, size=size)
 
 
-class DensityDist(Distribution):
-    """A distribution that can be used to wrap black-box log density functions.
+class _CustomDist(Distribution):
+    """A distribution that returns a subclass of CustomDistRV"""
 
-    Creates a Distribution and registers the supplied log density function to be used
-    for inference. It is also possible to supply a `random` method in order to be able
-    to sample from the prior or posterior predictive distributions.
-
-
-    Parameters
-    ----------
-    name : str
-    dist_params : Tuple
-        A sequence of the distribution's parameter. These will be converted into
-        Aesara tensors internally. These parameters could be other ``TensorVariable``
-        instances created from , optionally created via ``RandomVariable`` ``Op``s.
-    class_name : str
-        Name for the RandomVariable class which will wrap the DensityDist methods.
-        When not specified, it will be given the name of the variable.
-
-        .. warning:: New DensityDists created with the same class_name will override the
-            methods dispatched onto the previous classes. If using DensityDists with
-            different methods across separate models, be sure to use distinct
-            class_names.
-
-    logp : Optional[Callable]
-        A callable that calculates the log density of some given observed ``value``
-        conditioned on certain distribution parameter values. It must have the
-        following signature: ``logp(value, *dist_params)``, where ``value`` is
-        an Aesara tensor that represents the observed value, and ``dist_params``
-        are the tensors that hold the values of the distribution parameters.
-        This function must return an Aesara tensor. If ``None``, a ``NotImplemented``
-        error will be raised when trying to compute the distribution's logp.
-    logcdf : Optional[Callable]
-        A callable that calculates the log cummulative probability of some given observed
-        ``value`` conditioned on certain distribution parameter values. It must have the
-        following signature: ``logcdf(value, *dist_params)``, where ``value`` is
-        an Aesara tensor that represents the observed value, and ``dist_params``
-        are the tensors that hold the values of the distribution parameters.
-        This function must return an Aesara tensor. If ``None``, a ``NotImplemented``
-        error will be raised when trying to compute the distribution's logcdf.
-    random : Optional[Callable]
-        A callable that can be used to generate random draws from the distribution.
-        It must have the following signature: ``random(*dist_params, rng=None, size=None)``.
-        The distribution parameters are passed as positional arguments in the
-        same order as they are supplied when the ``DensityDist`` is constructed.
-        The keyword arguments are ``rnd``, which will provide the random variable's
-        associated :py:class:`~numpy.random.Generator`, and ``size``, that will represent
-        the desired size of the random draw. If ``None``, a ``NotImplemented``
-        error will be raised when trying to draw random samples from the distribution's
-        prior or posterior predictive.
-    moment : Optional[Callable]
-        A callable that can be used to compute the moments of the distribution.
-        It must have the following signature: ``moment(rv, size, *rv_inputs)``.
-        The distribution's :class:`~aesara.tensor.random.op.RandomVariable` is passed
-        as the first argument ``rv``. ``size`` is the random variable's size implied
-        by the ``dims``, ``size`` and parameters supplied to the distribution. Finally,
-        ``rv_inputs`` is the sequence of the distribution parameters, in the same order
-        as they were supplied when the DensityDist was created. If ``None``, a default
-        ``moment`` function will be assigned that will always return 0, or an array
-        of zeros.
-    ndim_supp : int
-        The number of dimensions in the support of the distribution. Defaults to assuming
-        a scalar distribution, i.e. ``ndim_supp = 0``.
-    ndims_params : Optional[Sequence[int]]
-        The list of number of dimensions in the support of each of the distribution's
-        parameters. If ``None``, it is assumed that all parameters are scalars, hence
-        the number of dimensions of their support will be 0.
-    dtype : str
-        The dtype of the distribution. All draws and observations passed into the distribution
-        will be casted onto this dtype.
-    kwargs :
-        Extra keyword arguments are passed to the parent's class ``__new__`` method.
-
-    Examples
-    --------
-        .. code-block:: python
-
-            def logp(value, mu):
-                return -(value - mu)**2
-
-            with pm.Model():
-                mu = pm.Normal('mu',0,1)
-                pm.DensityDist(
-                    'density_dist',
-                    mu,
-                    logp=logp,
-                    observed=np.random.randn(100),
-                )
-                idata = pm.sample(100)
-
-        .. code-block:: python
-
-            def logp(value, mu):
-                return -(value - mu)**2
-
-            def random(mu, rng=None, size=None):
-                return rng.normal(loc=mu, scale=1, size=size)
-
-            with pm.Model():
-                mu = pm.Normal('mu', 0 , 1)
-                dens = pm.DensityDist(
-                    'density_dist',
-                    mu,
-                    logp=logp,
-                    random=random,
-                    observed=np.random.randn(100, 3),
-                    size=(100, 3),
-                )
-                prior = pm.sample_prior_predictive(10).prior_predictive['density_dist']
-            assert prior.shape == (1, 10, 100, 3)
-
-    """
-
-    rv_type = DensityDistRV
-
-    def __new__(cls, name, *args, **kwargs):
-        kwargs.setdefault("class_name", name)
-        if isinstance(kwargs.get("observed", None), dict):
-            raise TypeError(
-                "Since ``v4.0.0`` the ``observed`` parameter should be of type"
-                " ``pd.Series``, ``np.array``, or ``pm.Data``."
-                " Previous versions allowed passing distribution parameters as"
-                " a dictionary in ``observed``, in the current version these "
-                "parameters are positional arguments."
-            )
-        return super().__new__(cls, name, *args, **kwargs)
+    rv_type = CustomDistRV
 
     @classmethod
     def dist(
@@ -602,17 +498,7 @@ class DensityDist(Distribution):
         **kwargs,
     ):
 
-        if dist_params is None:
-            dist_params = []
-        elif len(dist_params) > 0 and callable(dist_params[0]):
-            raise TypeError(
-                "The DensityDist API has changed, you are using the old API "
-                "where logp was the first positional argument. In the current API, "
-                "the logp is a keyword argument, amongst other changes. Please refer "
-                "to the API documentation for more information on how to use the "
-                "new DensityDist API."
-            )
-            dist_params = [as_tensor_variable(param) for param in dist_params]
+        dist_params = [as_tensor_variable(param) for param in dist_params]
 
         # Assume scalar ndims_params
         if ndims_params is None:
@@ -662,44 +548,532 @@ class DensityDist(Distribution):
         dtype: str,
         **kwargs,
     ):
-        rv_op = type(
-            f"DensityDist_{class_name}",
-            (DensityDistRV,),
+        rv_type = type(
+            f"CustomDistRV_{class_name}",
+            (CustomDistRV,),
             dict(
-                name=f"DensityDist_{class_name}",
+                name=f"CustomDist_{class_name}",
                 inplace=False,
                 ndim_supp=ndim_supp,
                 ndims_params=ndims_params,
                 dtype=dtype,
-                # Specifc to DensityDist
+                # Specific to CustomDist
                 _random_fn=random,
             ),
-        )()
-
-        # Register custom logp
-        rv_type = type(rv_op)
+        )
 
+        # Dispatch custom methods
         @_logprob.register(rv_type)
-        def density_dist_logp(op, value_var_list, *dist_params, **kwargs):
-            _dist_params = dist_params[3:]
-            value_var = value_var_list[0]
-            return logp(value_var, *_dist_params)
+        def custom_dist_logp(op, values, rng, size, dtype, *dist_params, **kwargs):
+            return logp(values[0], *dist_params)
 
         @_logcdf.register(rv_type)
-        def density_dist_logcdf(op, var, rvs_to_values, *dist_params, **kwargs):
-            value_var = rvs_to_values.get(var, var)
-            return logcdf(value_var, *dist_params, **kwargs)
+        def density_dist_logcdf(op, value, rng, size, dtype, *dist_params, **kwargs):
+            return logcdf(value, *dist_params, **kwargs)
 
         @_moment.register(rv_type)
         def density_dist_get_moment(op, rv, rng, size, dtype, *dist_params):
             return moment(rv, size, *dist_params)
 
+        rv_op = rv_type()
         return rv_op(*dist_params, **kwargs)
 
 
+class CustomSymbolicDistRV(SymbolicRandomVariable):
+    """
+    Base class for CustomSymbolicDist
+
+    This should be subclassed when defining custom CustomDist objects that have
+    symbolic random methods.
+    """
+
+    default_output = -1
+
+    _print_name = ("CustomSymbolicDist", "\\operatorname{CustomSymbolicDist}")
+
+    def update(self, node: Node):
+        op = node.op
+        inner_updates = collect_default_updates(op.inner_inputs, op.inner_outputs)
+
+        # Map inner updates to outer inputs/outputs
+        updates = {}
+        for rng, update in inner_updates.items():
+            inp_idx = op.inner_inputs.index(rng)
+            out_idx = op.inner_outputs.index(update)
+            updates[node.inputs[inp_idx]] = node.outputs[out_idx]
+        return updates
+
+
+class _CustomSymbolicDist(Distribution):
+
+    rv_type = CustomSymbolicDistRV
+
+    @classmethod
+    def dist(
+        cls,
+        *dist_params,
+        class_name: str,
+        random: Callable,
+        logp: Optional[Callable] = None,
+        logcdf: Optional[Callable] = None,
+        moment: Optional[Callable] = None,
+        ndim_supp: int = 0,
+        dtype: str = "floatX",
+        **kwargs,
+    ):
+        warnings.warn(
+            "CustomDist with symbolic random graph is still experimental. Expect bugs!",
+            UserWarning,
+        )
+
+        dist_params = [as_tensor_variable(param) for param in dist_params]
+
+        if logcdf is None:
+            logcdf = default_not_implemented(class_name, "logcdf")
+
+        if moment is None:
+            moment = functools.partial(
+                default_moment,
+                rv_name=class_name,
+                has_fallback=True,
+                ndim_supp=ndim_supp,
+            )
+
+        return super().dist(
+            dist_params,
+            class_name=class_name,
+            logp=logp,
+            logcdf=logcdf,
+            random=random,
+            moment=moment,
+            ndim_supp=ndim_supp,
+            **kwargs,
+        )
+
+    @classmethod
+    def rv_op(
+        cls,
+        *dist_params,
+        class_name: str,
+        random: Callable,
+        logp: Optional[Callable],
+        logcdf: Optional[Callable],
+        moment: Optional[Callable],
+        size=None,
+        ndim_supp: int,
+    ):
+        size = normalize_size_param(size)
+        dummy_size_param = size.type()
+        dummy_dist_params = [dist_param.type() for dist_param in dist_params]
+        with BlockModelAccess(
+            error_msg_on_access="Model variables cannot be created in the random function. Use the `.dist` API"
+        ):
+            dummy_rv = random(*dummy_dist_params, dummy_size_param)
+        dummy_params = [dummy_size_param] + dummy_dist_params
+        dummy_updates_dict = collect_default_updates(dummy_params, (dummy_rv,))
+
+        rv_type = type(
+            f"CustomSymbolicDistRV_{class_name}",
+            (CustomSymbolicDistRV,),
+            # If logp is not provided, we infer it from the random graph
+            dict(
+                inline_logprob=logp is None,
+            ),
+        )
+
+        # Dispatch custom methods
+        if logp is not None:
+
+            @_logprob.register(rv_type)
+            def custom_dist_logp(op, values, size, *params, **kwargs):
+                return logp(values[0], *params[: len(dist_params)])
+
+        @_logcdf.register(rv_type)
+        def custom_dist_logcdf(op, value, size, *params, **kwargs):
+            return logcdf(value, *params[: len(dist_params)])
+
+        @_moment.register(rv_type)
+        def custom_dist_get_moment(op, rv, size, *params):
+            return moment(rv, size, *params[: len(params)])
+
+        @_change_dist_size.register(rv_type)
+        def change_custom_symbolic_dist_size(op, dist, new_size, expand):
+            node = dist.owner
+
+            if expand:
+                shape = tuple(dist.shape)
+                old_size = shape[: len(shape) - node.op.ndim_supp]
+                new_size = tuple(new_size) + tuple(old_size)
+            new_size = at.as_tensor(new_size, ndim=1, dtype="int64")
+
+            old_size, *old_dist_params = node.inputs[: len(dist_params) + 1]
+
+            # OpFromGraph has to be recreated if the size type changes!
+            dummy_size_param = new_size.type()
+            dummy_dist_params = [dist_param.type() for dist_param in old_dist_params]
+            dummy_rv = random(*dummy_dist_params, dummy_size_param)
+            dummy_params = [dummy_size_param] + dummy_dist_params
+            dummy_updates_dict = collect_default_updates(dummy_params, (dummy_rv,))
+            new_rv_op = rv_type(
+                inputs=dummy_params,
+                outputs=[*dummy_updates_dict.values(), dummy_rv],
+                ndim_supp=ndim_supp,
+            )
+            new_rv = new_rv_op(new_size, *dist_params)
+
+            return new_rv
+
+        rv_op = rv_type(
+            inputs=dummy_params,
+            outputs=[*dummy_updates_dict.values(), dummy_rv],
+            ndim_supp=ndim_supp,
+        )
+        return rv_op(size, *dist_params)
+
+
+class CustomDist:
+    """A helper class to create custom distributions
+
+    This class can be used to wrap black-box random and logp methods for use in
+    forward and mcmc sampling.
+
+    A user can provide a `random` function that returns numerical draws (e.g., via
+    NumPy routines) or an Aesara graph that represents the random graph when evaluated.
+
+    A user can provide a `logp` function that must return an Aesara graph that
+    represents the logp graph when evaluated. This is used for mcmc sampling. In some
+    cases, if a user provides a `random` function that returns an Aesara graph, PyMC
+    will be able to automatically derive the appropriate `logp` graph when performing
+    MCMC sampling.
+
+    Additionally, a user can provide a `logcdf` and `moment` functions that must return
+    an Aesara graph that computes those quantities. These may be used by other PyMC
+    routines.
+
+    Parameters
+    ----------
+    name : str
+    dist_params : Tuple
+        A sequence of the distribution's parameter. These will be converted into
+        Pytensor tensor variables internally.
+    class_name : str
+        Name for the class which will wrap the CustomDist methods. When not specified,
+        it will be given the name of the model variable.
+
+        .. warning:: New CustomDists created with the same class_name will override the
+            methods dispatched onto the previous classes. If using CustomDists with
+            different methods across separate models, be sure to use distinct
+            class_names.
+
+    random : Optional[Callable]
+        A callable that can be used to 1) generate random draws from the distribution or
+        2) returns an Aesara graph that represents the random draws.
+
+        If 1) it must have the following signature: ``random(*dist_params, rng=None, size=None)``.
+        The numerical distribution parameters are passed as positional arguments in the
+        same order as they are supplied when the ``CustomDist`` is constructed.
+        The keyword arguments are ``rng``, which will provide the random variable's
+        associated :py:class:`~numpy.random.Generator`, and ``size``, that will represent
+        the desired size of the random draw. If ``None``, a ``NotImplemented``
+        error will be raised when trying to draw random samples from the distribution's
+        prior or posterior predictive.
+
+        If 2) it must have the following signature: ``random(*dist_params, size)``.
+        The symbolic tensor distribution parameters are passed as postional arguments in
+        the same order as they are supplied when the ``CustomDist`` is constructed.
+    logp : Optional[Callable]
+        A callable that calculates the log probability of some given ``value``
+        conditioned on certain distribution parameter values. It must have the
+        following signature: ``logp(value, *dist_params)``, where ``value`` is
+        an PyTensor tensor that represents the distribution value, and ``dist_params``
+        are the tensors that hold the values of the distribution parameters.
+        This function must return an PyTensor tensor.
+
+        When the `random` function is specified and returns an `Aesara` graph, PyMC
+        will try to automatically infer the `logp` when this is not provided.
+
+        Otherwise, a ``NotImplementedError`` will be raised when trying to compute the
+        distribution's logp.
+    logcdf : Optional[Callable]
+        A callable that calculates the log cumulative log probability of some given
+        ``value`` conditioned on certain distribution parameter values. It must have the
+        following signature: ``logcdf(value, *dist_params)``, where ``value`` is
+        an PyTensor tensor that represents the distribution value, and ``dist_params``
+        are the tensors that hold the values of the distribution parameters.
+        This function must return an PyTensor tensor. If ``None``, a ``NotImplementedError``
+        will be raised when trying to compute the distribution's logcdf.
+    moment : Optional[Callable]
+        A callable that can be used to compute the moments of the distribution.
+        It must have the following signature: ``moment(rv, size, *rv_inputs)``.
+        The distribution's variable is passed as the first argument ``rv``. ``size``
+        is the random variable's size implied by the ``dims``, ``size`` and parameters
+        supplied to the distribution. Finally, ``rv_inputs`` is the sequence of the
+        distribution parameters, in the same order as they were supplied when the
+        CustomDist was created. If ``None``, a default  ``moment`` function will be
+        assigned that will always return 0, or an array of zeros.
+    ndim_supp : int
+        The number of dimensions in the support of the distribution. Defaults to assuming
+        a scalar distribution, i.e. ``ndim_supp = 0``.
+    ndims_params : Optional[Sequence[int]]
+        The list of number of dimensions in the support of each of the distribution's
+        parameters. If ``None``, it is assumed that all parameters are scalars, hence
+        the number of dimensions of their support will be 0. This is not needed if an
+        Aesara random function is provided
+    dtype : str
+        The dtype of the distribution. All draws and observations passed into the
+        distribution will be cast onto this dtype. This is not needed if an Aesara
+        random function is provided, which should already return the right dtype!
+    kwargs :
+        Extra keyword arguments are passed to the parent's class ``__new__`` method.
+
+
+    Examples
+    --------
+    Create a CustomDist that wraps a black-box logp function. This variable cannot be
+    used in prior or posterior predictive sampling because no random function was provided
+
+    .. code-block:: python
+
+        import numpy as np
+        import pymc as pm
+        from pytensor.tensor import TensorVariable
+
+        def logp(value: TensorVariable, mu: TensorVariable) -> TensorVariable:
+            return -(value - mu)**2
+
+        with pm.Model():
+            mu = pm.Normal('mu',0,1)
+            pm.CustomDist(
+                'custom_dist',
+                mu,
+                logp=logp,
+                observed=np.random.randn(100),
+            )
+            idata = pm.sample(100)
+
+    Provide a random function that return numerical draws. This allows one to use a
+    CustomDist in prior and posterior predictive sampling.
+
+    .. code-block:: python
+
+        from typing import Optional, Tuple
+
+        import numpy as np
+        import pymc as pm
+        from pytensor.tensor import TensorVariable
+
+        def logp(value: TensorVariable, mu: TensorVariable) -> TensorVariable:
+            return -(value - mu)**2
+
+        def random(
+            mu: np.ndarray | float,
+            rng: Optional[np.random.Generator] = None,
+            size : Optional[Tuple[int]]=None,
+        ) -> np.ndarray | float :
+            return rng.normal(loc=mu, scale=1, size=size)
+
+        with pm.Model():
+            mu = pm.Normal('mu', 0 , 1)
+            pm.CustomDist(
+                'custom_dist',
+                mu,
+                logp=logp,
+                random=random,
+                observed=np.random.randn(100, 3),
+                size=(100, 3),
+            )
+            prior = pm.sample_prior_predictive(10)
+
+    Provide a random function that creates an Aesara random graph. PyMC can
+    automatically infer that the logp of this variable corresponds to a shifted
+    Exponential distribution.
+
+    .. code-block:: python
+
+        import pymc as pm
+        from pytensor.tensor import TensorVariable
+
+        def random(
+            lam: TensorVariable,
+            shift: TensorVariable,
+            size: TensorVariable,
+        ) -> TensorVariable:
+            return pm.Exponential.dist(lam, size=size) + shift
+
+        with pm.Model() as m:
+            lam = pm.HalfNormal("lam")
+            shift = -1
+            pm.CustomDist(
+                "custom_dist",
+                lam,
+                shift,
+                random=random,
+                observed=[-1, -1, 0],
+            )
+
+            prior = pm.sample_prior_predictive()
+            posterior = pm.sample()
+
+    Provide a random function that creates an Aesara random graph. PyMC can
+    automatically infer that the logp of this variable corresponds to a
+    modified-PERT distribution.
+
+    .. code-block:: python
+
+       import pymc as pm
+       from pytensor.tensor import TensorVariable
+
+        def pert(
+            low: Tensorvariable,
+            peak: Tensorvariable,
+            high: Tensorvariable,
+            lmbda: Tensorvariable,
+            size: Tensorvariable,
+        ) -> Tensorvariable:
+            range = (high - low)
+            s_alpha = 1 + lmbda * (peak - low) / range
+            s_beta = 1 + lmbda * (high - peak) / range
+            return pm.Beta.dist(s_alpha, s_beta, size=size) * range + low
+
+        with pm.Model() as m:
+            low = pm.Normal("low", 0, 10)
+            peak = pm.Normal("peak", 50, 10)
+            high = pm.Normal("high", 100, 10)
+            lmbda = 4
+            pm.CustomDist("pert", low, peak, high, lmbda, random=pert, observed=[30, 35, 73])
+
+        m.point_logps()
+
+    """
+
+    def __new__(
+        cls,
+        name,
+        *dist_params,
+        random: Optional[Callable] = None,
+        logp: Optional[Callable] = None,
+        logcdf: Optional[Callable] = None,
+        moment: Optional[Callable] = None,
+        ndim_supp: int = 0,
+        ndims_params: Optional[Sequence[int]] = None,
+        dtype: str = "floatX",
+        **kwargs,
+    ):
+        if isinstance(kwargs.get("observed", None), dict):
+            raise TypeError(
+                "Since ``v4.0.0`` the ``observed`` parameter should be of type"
+                " ``pd.Series``, ``np.array``, or ``pm.Data``."
+                " Previous versions allowed passing distribution parameters as"
+                " a dictionary in ``observed``, in the current version these "
+                "parameters are positional arguments."
+            )
+        dist_params = cls.parse_dist_params(dist_params)
+        if cls.is_symbolic_random(random, dist_params):
+            return _CustomSymbolicDist(
+                name,
+                *dist_params,
+                class_name=name,
+                random=random,
+                logp=logp,
+                logcdf=logcdf,
+                moment=moment,
+                ndim_supp=ndim_supp,
+                **kwargs,
+            )
+        else:
+            return _CustomDist(
+                name,
+                *dist_params,
+                class_name=name,
+                random=random,
+                logp=logp,
+                logcdf=logcdf,
+                moment=moment,
+                ndim_supp=ndim_supp,
+                ndims_params=ndims_params,
+                dtype=dtype,
+                **kwargs,
+            )
+        return super().__new__(cls, name, *args, **kwargs)
+
+    @classmethod
+    def dist(
+        cls,
+        *dist_params,
+        class_name: str,
+        random: Optional[Callable] = None,
+        logp: Optional[Callable] = None,
+        logcdf: Optional[Callable] = None,
+        moment: Optional[Callable] = None,
+        ndim_supp: int = 0,
+        ndims_params: Optional[Sequence[int]] = None,
+        dtype: str = "floatX",
+        **kwargs,
+    ):
+        dist_params = cls.parse_dist_params(dist_params)
+        if cls.is_symbolic_random(random, dist_params):
+            return _CustomSymbolicDist.dist(
+                *dist_params,
+                class_name=class_name,
+                random=random,
+                logp=logp,
+                logcdf=logcdf,
+                moment=moment,
+                ndim_supp=ndim_supp,
+                **kwargs,
+            )
+        else:
+            return _CustomDist.dist(
+                *dist_params,
+                class_name=class_name,
+                random=random,
+                logp=logp,
+                logcdf=logcdf,
+                moment=moment,
+                ndim_supp=ndim_supp,
+                ndims_params=ndims_params,
+                dtype=dtype,
+                **kwargs,
+            )
+
+    @classmethod
+    def parse_dist_params(cls, dist_params):
+        if len(dist_params) > 0 and callable(dist_params[0]):
+            raise TypeError(
+                "The DensityDist API has changed, you are using the old API "
+                "where logp was the first positional argument. In the current API, "
+                "the logp is a keyword argument, amongst other changes. Please refer "
+                "to the API documentation for more information on how to use the "
+                "new DensityDist API."
+            )
+        return [as_tensor_variable(param) for param in dist_params]
+
+    @classmethod
+    def is_symbolic_random(self, random, dist_params):
+        if random is None:
+            return False
+        # Try calling random with symbolic inputs
+        try:
+            size = normalize_size_param(None)
+            with BlockModelAccess(
+                error_msg_on_access="Model variables cannot be created in the random function. Use the `.dist` API"
+            ):
+                out = random(*dist_params, size)
+        except BlockModelAccessError:
+            raise
+        except Exception:
+            # If it fails we assume it was not
+            return False
+        # Confirm the output is symbolic
+        return isinstance(out, Variable)
+
+
+DensityDist = CustomDist
+
+
 def default_not_implemented(rv_name, method_name):
     message = (
-        f"Attempted to run {method_name} on the DensityDist '{rv_name}', "
+        f"Attempted to run {method_name} on the CustomDist '{rv_name}', "
         f"but this method had not been provided when the distribution was "
         f"constructed. Please re-build your model and provide a callable "
         f"to '{rv_name}'s {method_name} keyword argument.\n"
