@@ -13,15 +13,13 @@
 #   limitations under the License.
 import warnings
 
-import aesara
-import aesara.tensor as at
 import numpy as np
+import pytensor
+import pytensor.tensor as at
 
-from aeppl.logprob import _logcdf, _logprob
-from aeppl.transforms import IntervalTransform
-from aesara.graph.basic import Node, equal_computations
-from aesara.tensor import TensorVariable
-from aesara.tensor.random.op import RandomVariable
+from pytensor.graph.basic import Node, equal_computations
+from pytensor.tensor import TensorVariable
+from pytensor.tensor.random.op import RandomVariable
 
 from pymc.distributions import transforms
 from pymc.distributions.continuous import Normal, get_tau_sigma
@@ -35,6 +33,8 @@ from pymc.distributions.distribution import (
 from pymc.distributions.logprob import ignore_logprob, logcdf, logp
 from pymc.distributions.shape_utils import _change_dist_size, change_dist_size
 from pymc.distributions.transforms import _default_transform
+from pymc.logprob.abstract import _logcdf, _logprob
+from pymc.logprob.transforms import IntervalTransform
 from pymc.util import check_dist_not_registered
 from pymc.vartypes import continuous_types, discrete_types
 
@@ -210,7 +210,7 @@ class Mixture(Distribution):
     @classmethod
     def rv_op(cls, weights, *components, size=None):
         # Create new rng for the mix_indexes internal RV
-        mix_indexes_rng = aesara.shared(np.random.default_rng())
+        mix_indexes_rng = pytensor.shared(np.random.default_rng())
 
         single_component = len(components) == 1
         ndim_supp = components[0].owner.op.ndim_supp
@@ -254,7 +254,7 @@ class Mixture(Distribution):
         assert weights_ndim_batch == 0
 
         # Component RVs terms are accounted by the Mixture logprob, so they can be
-        # safely ignored by Aeppl
+        # safely ignored in the logprob graph
         components = [ignore_logprob(component) for component in components]
 
         # Create a OpFromGraph that encapsulates the random generating process
