@@ -20,28 +20,26 @@ import warnings
 from functools import reduce
 from typing import Optional
 
-import aesara
-import aesara.tensor as at
 import numpy as np
+import pytensor
+import pytensor.tensor as at
 import scipy
 
-from aeppl.logprob import _logprob
-from aesara.graph.basic import Apply, Constant, Variable
-from aesara.graph.op import Op
-from aesara.raise_op import Assert
-from aesara.sparse.basic import sp_sum
-from aesara.tensor import TensorConstant, gammaln, sigmoid
-from aesara.tensor.nlinalg import det, eigh, matrix_inverse, trace
-from aesara.tensor.random.basic import dirichlet, multinomial, multivariate_normal
-from aesara.tensor.random.op import RandomVariable, default_supp_shape_from_params
-from aesara.tensor.random.utils import broadcast_params
-from aesara.tensor.slinalg import Cholesky, SolveTriangular
-from aesara.tensor.type import TensorType
+from pytensor.graph.basic import Apply, Constant, Variable
+from pytensor.graph.op import Op
+from pytensor.raise_op import Assert
+from pytensor.sparse.basic import sp_sum
+from pytensor.tensor import TensorConstant, gammaln, sigmoid
+from pytensor.tensor.nlinalg import det, eigh, matrix_inverse, trace
+from pytensor.tensor.random.basic import dirichlet, multinomial, multivariate_normal
+from pytensor.tensor.random.op import RandomVariable, default_supp_shape_from_params
+from pytensor.tensor.random.utils import broadcast_params
+from pytensor.tensor.slinalg import Cholesky, SolveTriangular
+from pytensor.tensor.type import TensorType
 from scipy import linalg, stats
 
 import pymc as pm
 
-from pymc.aesaraf import floatX, intX
 from pymc.distributions import transforms
 from pymc.distributions.continuous import BoundedContinuous, ChiSquared, Normal
 from pymc.distributions.dist_math import (
@@ -69,7 +67,9 @@ from pymc.distributions.shape_utils import (
     to_tuple,
 )
 from pymc.distributions.transforms import Interval, ZeroSumTransform, _default_transform
+from pymc.logprob.abstract import _logprob
 from pymc.math import kron_diag, kron_dot
+from pymc.pytensorf import floatX, intX
 from pymc.util import check_dist_not_registered
 
 __all__ = [
@@ -126,7 +126,7 @@ def quaddist_matrix(cov=None, chol=None, tau=None, lower=True, *args, **kwargs):
         if tau.ndim != 2:
             raise ValueError("tau must be two dimensional.")
         # TODO: What's the correct order/approach (in the non-square case)?
-        # `aesara.tensor.nlinalg.tensorinv`?
+        # `pytensor.tensor.nlinalg.tensorinv`?
         cov = matrix_inverse(tau)
     else:
         # TODO: What's the correct order/approach (in the non-square case)?
@@ -260,7 +260,7 @@ class MvNormal(Continuous):
     def dist(cls, mu, cov=None, tau=None, chol=None, lower=True, **kwargs):
         mu = at.as_tensor_variable(mu)
         cov = quaddist_matrix(cov, chol, tau, lower)
-        # Aesara is stricter about the shape of mu, than PyMC used to be
+        # PyTensor is stricter about the shape of mu, than PyMC used to be
         mu = at.broadcast_arrays(mu, cov[..., -1])[0]
         return super().dist([mu, cov], **kwargs)
 
@@ -288,7 +288,11 @@ class MvNormal(Continuous):
         quaddist, logdet, ok = quaddist_parse(value, mu, cov)
         k = floatX(value.shape[-1])
         norm = -0.5 * k * pm.floatX(np.log(2 * np.pi))
-        return check_parameters(norm - 0.5 * quaddist - logdet, ok)
+        return check_parameters(
+            norm - 0.5 * quaddist - logdet,
+            ok,
+            msg="posdef",
+        )
 
 
 class MvStudentTRV(RandomVariable):
@@ -307,7 +311,7 @@ class MvStudentTRV(RandomVariable):
 
     def __call__(self, nu, mu=None, cov=None, size=None, **kwargs):
 
-        dtype = aesara.config.floatX if self.dtype == "floatX" else self.dtype
+        dtype = pytensor.config.floatX if self.dtype == "floatX" else self.dtype
 
         if mu is None:
             mu = np.array([0.0], dtype=dtype)
@@ -396,7 +400,7 @@ class MvStudentT(Continuous):
         nu = at.as_tensor_variable(floatX(nu))
         mu = at.as_tensor_variable(floatX(mu))
         scale = quaddist_matrix(scale, chol, tau, lower)
-        # Aesara is stricter about the shape of mu, than PyMC used to be
+        # PyTensor is stricter about the shape of mu, than PyMC used to be
         mu = at.broadcast_arrays(mu, scale[..., -1])[0]
 
         return super().dist([nu, mu, scale], **kwargs)
@@ -429,11 +433,7 @@ class MvStudentT(Continuous):
         inner = -(nu + k) / 2.0 * at.log1p(quaddist / nu)
         res = norm + inner - logdet
 
-        return check_parameters(
-            res,
-            ok,
-            nu > 0,
-        )
+        return check_parameters(res, ok, nu > 0, msg="posdef, nu > 0")
 
 
 class Dirichlet(SimplexContinuous):
@@ -596,7 +596,7 @@ class Multinomial(Discrete):
         )
         return check_parameters(
             res,
-            p >= 0,
+            0 <= p,
             p <= 1,
             at.isclose(at.sum(p, axis=-1), 1),
             at.ge(n, 0),
@@ -796,7 +796,6 @@ class OrderedMultinomial:
 
     Examples
     --------
-
     .. code-block:: python
 
         # Generate data for a simple 1 dimensional example problem
@@ -880,7 +879,7 @@ class PosDefMatrix(Op):
 
     def grad(self, inp, grads):
         (x,) = inp
-        return [x.zeros_like(aesara.config.floatX)]
+        return [x.zeros_like(pytensor.config.floatX)]
 
     def __str__(self):
         return "MatrixIsPositiveDefinite"
@@ -1219,7 +1218,7 @@ class _LKJCholeskyCov(Distribution):
             sd_dist = change_dist_size(sd_dist, shape[:-1])
 
         # Create new rng for the _lkjcholeskycov internal RV
-        rng = aesara.shared(np.random.default_rng())
+        rng = pytensor.shared(np.random.default_rng())
 
         rng_, n_, eta_, sd_dist_ = rng.type(), n.type(), eta.type(), sd_dist.type()
         next_rng_, lkjcov_ = _ljk_cholesky_cov_base(n_, eta_, sd_dist_, rng=rng_).owner.outputs
@@ -1301,7 +1300,7 @@ class LKJCholeskyCov:
 
     This defines a distribution over Cholesky decomposed covariance
     matrices, such that the underlying correlation matrices follow an
-    LKJ distribution [1] and the standard deviations follow an arbitray
+    LKJ distribution [1] and the standard deviations follow an arbitrary
     distribution specified by the user.
 
     Parameters
@@ -1392,7 +1391,7 @@ class LKJCholeskyCov:
     we use a log-transform to restrict them to positive values.
 
     To correctly compute log-likelihoods for the standard deviations
-    and the correlation matrix seperatly, we need to consider a
+    and the correlation matrix separately, we need to consider a
     second transformation: Given a cholesky factorization
     :math:`LL^T = \Sigma` of a covariance matrix we can recover the
     standard deviations :math:`\sigma` as the euclidean lengths of
@@ -1605,7 +1604,7 @@ class LKJCorr(BoundedContinuous):
         TensorVariable
         """
 
-        # TODO: Aesara does not have a `triu_indices`, so we can only work with constant
+        # TODO: PyTensor does not have a `triu_indices`, so we can only work with constant
         #  n (or else find a different expression)
         if not isinstance(n, Constant):
             raise NotImplementedError("logp only implemented for constant `n`")
@@ -1931,7 +1930,7 @@ class KroneckerNormal(Continuous):
         with pm.Model() as model:
             vals = pm.KroneckerNormal('vals', mu=mu, covs=covs, shape=N)
 
-    Effeciency gains are made by cholesky decomposing :math:`K_1` and
+    Efficiency gains are made by cholesky decomposing :math:`K_1` and
     :math:`K_2` individually rather than the larger :math:`K` matrix. Although
     only two matrices :math:`K_1` and :math:`K_2` are shown here, an arbitrary
     number of submatrices can be combined in this way. Choleskys and
@@ -2059,15 +2058,15 @@ class CARRV(RandomVariable):
     def make_node(self, rng, size, dtype, mu, W, alpha, tau):
         mu = at.as_tensor_variable(floatX(mu))
 
-        W = aesara.sparse.as_sparse_or_tensor_variable(floatX(W))
+        W = pytensor.sparse.as_sparse_or_tensor_variable(floatX(W))
         if not W.ndim == 2:
             raise ValueError("W must be a matrix (ndim=2).")
 
-        sparse = isinstance(W, aesara.sparse.SparseVariable)
+        sparse = isinstance(W, pytensor.sparse.SparseVariable)
         msg = "W must be a symmetric adjacency matrix."
         if sparse:
-            abs_diff = aesara.sparse.basic.mul(aesara.sparse.basic.sgn(W - W.T), W - W.T)
-            W = Assert(msg)(W, at.isclose(aesara.sparse.basic.sp_sum(abs_diff), 0))
+            abs_diff = pytensor.sparse.basic.mul(pytensor.sparse.basic.sgn(W - W.T), W - W.T)
+            W = Assert(msg)(W, at.isclose(pytensor.sparse.basic.sp_sum(abs_diff), 0))
         else:
             W = Assert(msg)(W, at.allclose(W, W.T))
 
@@ -2151,7 +2150,7 @@ class CAR(Continuous):
         Symmetric adjacency matrix of 1s and 0s indicating
         adjacency between elements. If possible, *W* is converted
         to a sparse matrix, falling back to a dense variable.
-        :func:`~aesara.sparse.basic.as_sparse_or_tensor_variable` is
+        :func:`~pytensor.sparse.basic.as_sparse_or_tensor_variable` is
         used for this sparse or tensorvariable conversion.
     alpha : tensor_like of float
         Autoregression parameter taking values between -1 and 1. Values closer to 0 indicate weaker
@@ -2192,12 +2191,12 @@ class CAR(Continuous):
         TensorVariable
         """
 
-        sparse = isinstance(W, (aesara.sparse.SparseConstant, aesara.sparse.SparseVariable))
+        sparse = isinstance(W, (pytensor.sparse.SparseConstant, pytensor.sparse.SparseVariable))
 
         if sparse:
             D = sp_sum(W, axis=0)
             Dinv_sqrt = at.diag(1 / at.sqrt(D))
-            DWD = at.dot(aesara.sparse.dot(Dinv_sqrt, W), Dinv_sqrt)
+            DWD = at.dot(pytensor.sparse.dot(Dinv_sqrt, W), Dinv_sqrt)
         else:
             D = W.sum(axis=0)
             Dinv_sqrt = at.diag(1 / at.sqrt(D))
@@ -2214,7 +2213,7 @@ class CAR(Continuous):
         delta = value - mu
 
         if sparse:
-            Wdelta = aesara.sparse.dot(delta, W)
+            Wdelta = pytensor.sparse.dot(delta, W)
         else:
             Wdelta = at.dot(delta, W)
 
@@ -2222,8 +2221,8 @@ class CAR(Continuous):
         logquad = (tau * delta * tau_dot_delta).sum(axis=-1)
         return check_parameters(
             0.5 * (logtau + logdet - logquad),
+            -1 <= alpha,
             alpha <= 1,
-            alpha >= -1,
             tau > 0,
             msg="-1 <= alpha <= 1, tau > 0",
         )
@@ -2434,7 +2433,7 @@ class ZeroSumNormal(Distribution):
     Warnings
     --------
     ``sigma`` has to be a scalar, to ensure the zero-sum constraint.
-    The ability to specifiy a vector of ``sigma`` may be added in future versions.
+    The ability to specify a vector of ``sigma`` may be added in future versions.
 
     ``zerosum_axes`` has to be > 0. If you want the behavior of ``zerosum_axes = 0``,
     just use ``pm.Normal``.
@@ -2533,7 +2532,7 @@ class ZeroSumNormal(Distribution):
             support_shape.type(),
         )
 
-        # Zerosum-normaling is achieved by substracting the mean along the given zerosum_axes
+        # Zerosum-normaling is achieved by subtracting the mean along the given zerosum_axes
         zerosum_rv_ = normal_dist_
         for axis in range(zerosum_axes):
             zerosum_rv_ -= zerosum_rv_.mean(axis=-axis - 1, keepdims=True)
@@ -2591,4 +2590,4 @@ def zerosumnormal_logp(op, values, normal_dist, sigma, support_shape, **kwargs):
         axis=tuple(np.arange(-zerosum_axes, 0)),
     )
 
-    return check_parameters(out, *zerosums, msg="at.mean(value, axis=zerosum_axes) == 0")
+    return check_parameters(out, *zerosums, msg="mean(value, axis=zerosum_axes) = 0")
