@@ -17,16 +17,15 @@ import warnings
 from abc import ABCMeta
 from typing import Callable, Optional
 
-import aesara
-import aesara.tensor as at
 import numpy as np
+import pytensor
+import pytensor.tensor as at
 
-from aeppl.logprob import _logprob
-from aesara.graph.basic import Node, clone_replace
-from aesara.tensor import TensorVariable
-from aesara.tensor.random.op import RandomVariable
+from pytensor.graph.basic import Node
+from pytensor.graph.replace import clone_replace
+from pytensor.tensor import TensorVariable
+from pytensor.tensor.random.op import RandomVariable
 
-from pymc.aesaraf import constant_fold, floatX, intX
 from pymc.distributions.continuous import Normal, get_tau_sigma
 from pymc.distributions.distribution import (
     Distribution,
@@ -43,6 +42,8 @@ from pymc.distributions.shape_utils import (
     get_support_shape_1d,
 )
 from pymc.exceptions import NotConstantValueError
+from pymc.logprob.abstract import _logprob
+from pymc.pytensorf import constant_fold, floatX, intX
 from pymc.util import check_dist_not_registered
 
 __all__ = [
@@ -180,7 +181,7 @@ class RandomWalk(Distribution):
             innovation_dist.type(),
             steps.type(),
         )
-        # Aeppl can only infer the logp of a dimshuffled variables, if the dimshuffle is
+        # We can only infer the logp of a dimshuffled variables, if the dimshuffle is
         # done directly on top of a RandomVariable. Because of this we dimshuffle the
         # distributions and only then concatenate them, instead of the other way around.
         # shape = (B, 1, S)
@@ -225,15 +226,15 @@ def random_walk_moment(op, rv, init_dist, innovation_dist, steps):
 
 @_logprob.register(RandomWalkRV)
 def random_walk_logp(op, values, *inputs, **kwargs):
-    # Although Aeppl can derive the logprob of random walks, it does not collapse
-    # what PyMC considers the core dimension of steps. We do it manually here.
+    # Although we can derive the logprob of random walks, it does not collapse
+    # what we consider the core dimension of steps. We do it manually here.
     (value,) = values
     # Recreate RV and obtain inner graph
     rv_node = op.make_node(*inputs)
     rv = clone_replace(
         op.inner_outputs, replace={u: v for u, v in zip(op.inner_inputs, rv_node.inputs)}
     )[op.default_output]
-    # Obtain logp via Aeppl of inner graph and collapse steps dimension
+    # Obtain logp of the inner graph and collapse steps dimension
     return logp(rv, value).sum(axis=-1)
 
 
@@ -561,7 +562,7 @@ class AR(Distribution):
             )
             init_dist = Normal.dist(0, 100, shape=(*sigma.shape, ar_order))
 
-        # Tell Aeppl to ignore init_dist, as it will be accounted for in the logp term
+        # We can ignore init_dist, as it will be accounted for in the logp term
         init_dist = ignore_logprob(init_dist)
 
         return super().dist([rhos, sigma, init_dist, steps, ar_order, constant], **kwargs)
@@ -572,7 +573,7 @@ class AR(Distribution):
 
         If ar_order is not specified we do constant folding on the shape of rhos
         to retrieve it. For example, this will detect that
-        Normal(size=(5, 3)).shape[-1] == 3, which is not known by Aesara before.
+        Normal(size=(5, 3)).shape[-1] == 3, which is not known by PyTensor before.
 
         Raises
         ------
@@ -585,7 +586,7 @@ class AR(Distribution):
             except NotConstantValueError:
                 raise ValueError(
                     "Could not infer ar_order from last dimension of rho. Pass it "
-                    "explictily or make sure rho have a static shape"
+                    "explicitly or make sure rho have a static shape"
                 )
             ar_order = int(folded_shape) - int(constant)
             if ar_order < 1:
@@ -629,7 +630,7 @@ class AR(Distribution):
             rhos_bcast_shape_ = (*rhos_bcast_shape_[:-1], rhos_bcast_shape_[-1] + 1)
         rhos_bcast_ = at.broadcast_to(rhos_, rhos_bcast_shape_)
 
-        noise_rng = aesara.shared(np.random.default_rng())
+        noise_rng = pytensor.shared(np.random.default_rng())
 
         def step(*args):
             *prev_xs, reversed_rhos, sigma, rng = args
@@ -641,7 +642,7 @@ class AR(Distribution):
             return new_x, {rng: next_rng}
 
         # We transpose inputs as scan iterates over first dimension
-        innov_, innov_updates_ = aesara.scan(
+        innov_, innov_updates_ = pytensor.scan(
             fn=step,
             outputs_info=[{"initial": init_.T, "taps": range(-ar_order, 0)}],
             non_sequences=[rhos_bcast_.T[::-1], sigma_.T, noise_rng],
@@ -780,7 +781,7 @@ class GARCH11(Distribution):
         initial_vol = at.as_tensor_variable(initial_vol)
 
         init_dist = Normal.dist(0, initial_vol)
-        # Tell Aeppl to ignore init_dist, as it will be accounted for in the logp term
+        # We can ignore init_dist, as it will be accounted for in the logp term
         init_dist = ignore_logprob(init_dist)
 
         return super().dist([omega, alpha_1, beta_1, initial_vol, init_dist, steps], **kwargs)
@@ -804,7 +805,7 @@ class GARCH11(Distribution):
         beta_1_ = beta_1.type()
         steps_ = steps.type()
 
-        noise_rng = aesara.shared(np.random.default_rng())
+        noise_rng = pytensor.shared(np.random.default_rng())
 
         def step(prev_y, prev_sigma, omega, alpha_1, beta_1, rng):
             new_sigma = at.sqrt(
@@ -813,7 +814,7 @@ class GARCH11(Distribution):
             next_rng, new_y = Normal.dist(mu=0, sigma=new_sigma, rng=rng).owner.outputs
             return (new_y, new_sigma), {rng: next_rng}
 
-        (y_t, _), innov_updates_ = aesara.scan(
+        (y_t, _), innov_updates_ = pytensor.scan(
             fn=step,
             outputs_info=[init_, initial_vol_ * at.ones(batch_size)],
             non_sequences=[omega_, alpha_1_, beta_1_, noise_rng],
@@ -861,7 +862,7 @@ def garch11_logp(
     def volatility_update(x, vol, w, a, b):
         return at.sqrt(w + a * at.square(x) + b * at.square(vol))
 
-    vol, _ = aesara.scan(
+    vol, _ = pytensor.scan(
         fn=volatility_update,
         sequences=[value_dimswapped[:-1]],
         outputs_info=[initial_vol],
@@ -966,7 +967,7 @@ class EulerMaruyama(Distribution):
                 UserWarning,
             )
             init_dist = Normal.dist(0, 100, shape=sde_pars[0].shape)
-        # Tell Aeppl to ignore init_dist, as it will be accounted for in the logp term
+        # We can ignore init_dist, as it will be accounted for in the logp term
         init_dist = ignore_logprob(init_dist)
 
         return super().dist([init_dist, steps, sde_pars, dt, sde_fn], **kwargs)
@@ -986,7 +987,7 @@ class EulerMaruyama(Distribution):
         sde_pars_ = [x.type() for x in sde_pars]
         steps_ = steps.type()
 
-        noise_rng = aesara.shared(np.random.default_rng())
+        noise_rng = pytensor.shared(np.random.default_rng())
 
         def step(*prev_args):
             prev_y, *prev_sde_pars, rng = prev_args
@@ -996,7 +997,7 @@ class EulerMaruyama(Distribution):
             next_rng, next_y = Normal.dist(mu=mu, sigma=sigma, rng=rng).owner.outputs
             return next_y, {rng: next_rng}
 
-        y_t, innov_updates_ = aesara.scan(
+        y_t, innov_updates_ = pytensor.scan(
             fn=step,
             outputs_info=[init_],
             non_sequences=sde_pars_ + [noise_rng],
