@@ -18,13 +18,13 @@ from functools import reduce
 from numbers import Number
 from operator import add, mul
 
-import aesara
-import aesara.tensor as at
 import numpy as np
+import pytensor
+import pytensor.tensor as at
 
-from aesara.graph.basic import Variable
-from aesara.tensor.sharedvar import TensorSharedVariable
-from aesara.tensor.var import TensorConstant, TensorVariable
+from pytensor.graph.basic import Variable
+from pytensor.tensor.sharedvar import TensorSharedVariable
+from pytensor.tensor.var import TensorConstant, TensorVariable
 
 __all__ = [
     "Constant",
@@ -34,6 +34,7 @@ __all__ = [
     "Exponential",
     "Matern52",
     "Matern32",
+    "Matern12",
     "Linear",
     "Polynomial",
     "Cosine",
@@ -122,7 +123,7 @@ class Covariance:
 
     def __pow__(self, other):
         if (
-            isinstance(other, aesara.compile.SharedVariable)
+            isinstance(other, pytensor.compile.SharedVariable)
             and other.get_value().squeeze().shape == ()
         ):
             other = at.squeeze(other)
@@ -444,7 +445,7 @@ class Periodic(Stationary):
 
 class ExpQuad(Stationary):
     r"""
-    The Exponentiated Quadratic kernel.  Also refered to as the Squared
+    The Exponentiated Quadratic kernel.  Also referred to as the Squared
     Exponential, or Radial Basis Function kernel.
 
     .. math::
@@ -515,7 +516,9 @@ class Matern12(Stationary):
     r"""
     The Matern kernel with nu = 1/2
 
-    k(x, x') = \mathrm{exp}\left[ -\frac{(x - x')^2}{\ell} \right]
+    .. math::
+
+        k(x, x') = \mathrm{exp}\left[ -\frac{(x - x')^2}{\ell} \right]
     """
 
     def full(self, X, Xs=None):
@@ -606,7 +609,7 @@ class Polynomial(Linear):
 class WarpedInput(Covariance):
     r"""
     Warp the inputs of any kernel using an arbitrary function
-    defined using Aesara.
+    defined using PyTensor.
 
     .. math::
        k(x, x') = k(w(x), w(x'))
@@ -615,7 +618,7 @@ class WarpedInput(Covariance):
     ----------
     cov_func: Covariance
     warp_func: callable
-        Aesara function of X and additional optional arguments.
+        PyTensor function of X and additional optional arguments.
     args: optional, tuple or list of scalars or PyMC variables
         Additional inputs (besides X or Xs) to warp_func.
     """
@@ -645,7 +648,7 @@ class WarpedInput(Covariance):
 class Gibbs(Covariance):
     r"""
     The Gibbs kernel.  Use an arbitrary lengthscale function defined
-    using Aesara.  Only tested in one dimension.
+    using PyTensor.  Only tested in one dimension.
 
     .. math::
        k(x, x') = \sqrt{\frac{2\ell(x)\ell(x')}{\ell^2(x) + \ell^2(x')}}
@@ -655,7 +658,7 @@ class Gibbs(Covariance):
     Parameters
     ----------
     lengthscale_func: callable
-        Aesara function of X and additional optional arguments.
+        PyTensor function of X and additional optional arguments.
     args: optional, tuple or list of scalars or PyMC variables
         Additional inputs (besides X or Xs) to lengthscale_func.
     """
@@ -706,7 +709,7 @@ class Gibbs(Covariance):
 class ScaledCov(Covariance):
     r"""
     Construct a kernel by multiplying a base kernel with a scaling
-    function defined using Aesara.  The scaling function is
+    function defined using PyTensor.  The scaling function is
     non-negative, and can be parameterized.
 
     .. math::
@@ -717,7 +720,7 @@ class ScaledCov(Covariance):
     cov_func: Covariance
         Base kernel or covariance function
     scaling_func: callable
-        Aesara function of X and additional optional arguments.
+        PyTensor function of X and additional optional arguments.
     args: optional, tuple or list of scalars or PyMC variables
         Additional inputs (besides X or Xs) to lengthscale_func.
     """
