@@ -14,22 +14,21 @@
 
 import warnings
 
-import aesara.tensor as at
 import numpy as np
+import pytensor.tensor as at
 
-from aesara.compile import SharedVariable
-from aesara.tensor.slinalg import (  # noqa: W0611; pylint: disable=unused-import
+from pytensor.compile import SharedVariable
+from pytensor.tensor.slinalg import (  # noqa: W0611; pylint: disable=unused-import
     SolveTriangular,
     cholesky,
     solve,
 )
-from aesara.tensor.var import TensorConstant
+from pytensor.tensor.var import TensorConstant
 from scipy.cluster.vq import kmeans
 
-from pymc.aesaraf import compile_pymc, walk_model
-
 # Avoid circular dependency when importing modelcontext
 from pymc.distributions.distribution import Distribution
+from pymc.pytensorf import compile_pymc, walk_model
 
 _ = Distribution  # keep both pylint and black happy
 from pymc.model import modelcontext
@@ -189,7 +188,7 @@ def plot_gp_dist(
 ):
     """A helper function for plotting 1D GP posteriors from trace
 
-        Parameters
+    Parameters
     ----------
     ax: axes
         Matplotlib axes.
@@ -214,7 +213,6 @@ def plot_gp_dist(
 
     Returns
     -------
-
     ax: Matplotlib axes
     """
     import matplotlib.pyplot as plt
