@@ -15,23 +15,25 @@ os.environ["XLA_FLAGS"] = " ".join([f"--xla_force_host_platform_device_count={10
 
 from datetime import datetime
 
-import aesara.tensor as at
 import arviz as az
 import jax
 import numpy as np
+import pytensor.tensor as at
 
-from aeppl.logprob import CheckParameterValue
-from aesara.compile import SharedVariable, Supervisor, mode
-from aesara.graph.basic import clone_replace, graph_inputs
-from aesara.graph.fg import FunctionGraph
-from aesara.link.jax.dispatch import jax_funcify
-from aesara.raise_op import Assert
-from aesara.tensor import TensorVariable
-from aesara.tensor.shape import SpecifyShape
 from arviz.data.base import make_attrs
+from jax.experimental.maps import SerialLoop, xmap
+from pytensor.compile import SharedVariable, Supervisor, mode
+from pytensor.graph.basic import graph_inputs
+from pytensor.graph.fg import FunctionGraph
+from pytensor.graph.replace import clone_replace
+from pytensor.link.jax.dispatch import jax_funcify
+from pytensor.raise_op import Assert
+from pytensor.tensor import TensorVariable
+from pytensor.tensor.shape import SpecifyShape
 
 from pymc import Model, modelcontext
 from pymc.backends.arviz import find_constants, find_observations
+from pymc.logprob.utils import CheckParameterValue
 from pymc.util import RandomSeed, _get_seeds_per_chain, get_default_varnames
 
 warnings.warn("This module is experimental.")
@@ -70,7 +72,7 @@ def _replace_shared_variables(graph: List[TensorVariable]) -> List[TensorVariabl
 
     shared_variables = [var for var in graph_inputs(graph) if isinstance(var, SharedVariable)]
 
-    if any(hasattr(var, "default_update") for var in shared_variables):
+    if any(var.default_update is not None for var in shared_variables):
         raise ValueError(
             "Graph contains shared variables with default_update which cannot "
             "be safely replaced."
@@ -86,7 +88,7 @@ def get_jaxified_graph(
     inputs: Optional[List[TensorVariable]] = None,
     outputs: Optional[List[TensorVariable]] = None,
 ) -> List[TensorVariable]:
-    """Compile an Aesara graph into an optimized JAX function"""
+    """Compile an PyTensor graph into an optimized JAX function"""
 
     graph = _replace_shared_variables(outputs)
 
@@ -94,8 +96,8 @@ def get_jaxified_graph(
     # We need to add a Supervisor to the fgraph to be able to run the
     # JAX sequential optimizer without warnings. We made sure there
     # are no mutable input variables, so we only need to check for
-    # "destroyers". This should be automatically handled by Aesara
-    # once https://github.com/aesara-devs/aesara/issues/637 is fixed.
+    # "destroyers". This should be automatically handled by PyTensor
+    # once https://github.com/pytensor-devs/pytensor/issues/637 is fixed.
     fgraph.attach_feature(
         Supervisor(
             input
@@ -142,6 +144,27 @@ def _sample_stats_to_xarray(posterior):
     return data
 
 
+def _postprocess_samples(
+    jax_fn: List[TensorVariable],
+    raw_mcmc_samples: List[TensorVariable],
+    postprocessing_backend: str,
+    num_chunks: Optional[int] = None,
+) -> List[TensorVariable]:
+    if num_chunks is not None:
+        loop = xmap(
+            jax_fn,
+            in_axes=["chain", "samples", ...],
+            out_axes=["chain", "samples", ...],
+            axis_resources={"samples": SerialLoop(num_chunks)},
+        )
+        f = xmap(loop, in_axes=[...], out_axes=[...])
+        return f(*jax.device_put(raw_mcmc_samples, jax.devices(postprocessing_backend)[0]))
+    else:
+        return jax.vmap(jax.vmap(jax_fn))(
+            *jax.device_put(raw_mcmc_samples, jax.devices(postprocessing_backend)[0])
+        )
+
+
 def _blackjax_stats_to_dict(sample_stats, potential_energy) -> Dict:
     """Extract compatible stats from blackjax NUTS sampler
     with PyMC/Arviz naming conventions.
@@ -176,11 +199,13 @@ def _blackjax_stats_to_dict(sample_stats, potential_energy) -> Dict:
     return converted_stats
 
 
-def _get_log_likelihood(model: Model, samples, backend=None) -> Dict:
+def _get_log_likelihood(
+    model: Model, samples, backend=None, num_chunks: Optional[int] = None
+) -> Dict:
     """Compute log-likelihood for all observations"""
     elemwise_logp = model.logp(model.observed_RVs, sum=False)
     jax_fn = get_jaxified_graph(inputs=model.value_vars, outputs=elemwise_logp)
-    result = jax.vmap(jax.vmap(jax_fn))(*jax.device_put(samples, jax.devices(backend)[0]))
+    result = _postprocess_samples(jax_fn, samples, backend, num_chunks=num_chunks)
     return {v.name: r for v, r in zip(model.observed_RVs, result)}
 
 
@@ -274,6 +299,7 @@ def sample_blackjax_nuts(
     keep_untransformed: bool = False,
     chain_method: str = "parallel",
     postprocessing_backend: Optional[str] = None,
+    postprocessing_chunks: Optional[int] = None,
     idata_kwargs: Optional[Dict[str, Any]] = None,
 ) -> az.InferenceData:
     """
@@ -313,6 +339,10 @@ def sample_blackjax_nuts(
         "vectorized".
     postprocessing_backend : str, optional
         Specify how postprocessing should be computed. gpu or cpu
+    postprocessing_chunks: Optional[int], default None
+        Specify the number of chunks the postprocessing should be computed in. More
+        chunks reduces memory usage at the cost of losing some vectorization, None
+        uses jax.vmap
     idata_kwargs : dict, optional
         Keyword arguments for :func:`arviz.from_dict`. It also accepts a boolean as
         value for the ``log_likelihood`` key to indicate that the pointwise log
@@ -399,8 +429,8 @@ def sample_blackjax_nuts(
 
     print("Transforming variables...", file=sys.stdout)
     jax_fn = get_jaxified_graph(inputs=model.value_vars, outputs=vars_to_sample)
-    result = jax.vmap(jax.vmap(jax_fn))(
-        *jax.device_put(raw_mcmc_samples, jax.devices(postprocessing_backend)[0])
+    result = _postprocess_samples(
+        jax_fn, raw_mcmc_samples, postprocessing_backend, num_chunks=postprocessing_chunks
     )
     mcmc_samples = {v.name: r for v, r in zip(vars_to_sample, result)}
     mcmc_stats = _blackjax_stats_to_dict(stats, potential_energy)
@@ -412,11 +442,14 @@ def sample_blackjax_nuts(
     else:
         idata_kwargs = idata_kwargs.copy()
 
-    if idata_kwargs.pop("log_likelihood", bool(model.observed_RVs)):
+    if idata_kwargs.pop("log_likelihood", False):
         tic5 = datetime.now()
         print("Computing Log Likelihood...", file=sys.stdout)
         log_likelihood = _get_log_likelihood(
-            model, raw_mcmc_samples, backend=postprocessing_backend
+            model,
+            raw_mcmc_samples,
+            backend=postprocessing_backend,
+            num_chunks=postprocessing_chunks,
         )
         tic6 = datetime.now()
         print("Log Likelihood time = ", tic6 - tic5, file=sys.stdout)
@@ -473,10 +506,11 @@ def sample_numpyro_nuts(
     initvals: Optional[Union[StartDict, Sequence[Optional[StartDict]]]] = None,
     model: Optional[Model] = None,
     var_names: Optional[Sequence[str]] = None,
-    progress_bar: bool = True,
+    progressbar: bool = True,
     keep_untransformed: bool = False,
     chain_method: str = "parallel",
     postprocessing_backend: Optional[str] = None,
+    postprocessing_chunks: Optional[int] = None,
     idata_kwargs: Optional[Dict] = None,
     nuts_kwargs: Optional[Dict] = None,
 ) -> az.InferenceData:
@@ -510,7 +544,7 @@ def sample_numpyro_nuts(
     var_names : sequence of str, optional
         Names of variables for which to compute the posterior samples. Defaults to all
         variables in the posterior.
-    progress_bar : bool, default True
+    progressbar : bool, default True
         Whether or not to display a progress bar in the command line. The bar shows the
         percentage of completion, the sampling speed in samples per second (SPS), and
         the estimated remaining time until completion ("expected time of arrival"; ETA).
@@ -521,6 +555,10 @@ def sample_numpyro_nuts(
         "parallel", and "vectorized".
     postprocessing_backend : Optional[str]
         Specify how postprocessing should be computed. gpu or cpu
+    postprocessing_chunks: Optional[int], default None
+        Specify the number of chunks the postprocessing should be computed in. More
+        chunks reduces memory usage at the cost of losing some vectorization, None
+        uses jax.vmap
     idata_kwargs : dict, optional
         Keyword arguments for :func:`arviz.from_dict`. It also accepts a boolean as
         value for the ``log_likelihood`` key to indicate that the pointwise log
@@ -589,7 +627,7 @@ def sample_numpyro_nuts(
         num_chains=chains,
         postprocess_fn=None,
         chain_method=chain_method,
-        progress_bar=progress_bar,
+        progress_bar=progressbar,
     )
 
     tic2 = datetime.now()
@@ -621,8 +659,8 @@ def sample_numpyro_nuts(
 
     print("Transforming variables...", file=sys.stdout)
     jax_fn = get_jaxified_graph(inputs=model.value_vars, outputs=vars_to_sample)
-    result = jax.vmap(jax.vmap(jax_fn))(
-        *jax.device_put(raw_mcmc_samples, jax.devices(postprocessing_backend)[0])
+    result = _postprocess_samples(
+        jax_fn, raw_mcmc_samples, postprocessing_backend, num_chunks=postprocessing_chunks
     )
     mcmc_samples = {v.name: r for v, r in zip(vars_to_sample, result)}
 
@@ -634,11 +672,14 @@ def sample_numpyro_nuts(
     else:
         idata_kwargs = idata_kwargs.copy()
 
-    if idata_kwargs.pop("log_likelihood", bool(model.observed_RVs)):
+    if idata_kwargs.pop("log_likelihood", False):
         tic5 = datetime.now()
         print("Computing Log Likelihood...", file=sys.stdout)
         log_likelihood = _get_log_likelihood(
-            model, raw_mcmc_samples, backend=postprocessing_backend
+            model,
+            raw_mcmc_samples,
+            backend=postprocessing_backend,
+            num_chunks=postprocessing_chunks,
         )
         tic6 = datetime.now()
         print("Log Likelihood time = ", tic6 - tic5, file=sys.stdout)
