@@ -21,15 +21,14 @@ import time
 import warnings
 
 from collections import defaultdict
-from copy import copy
-from typing import Iterator, List, Optional, Sequence, Tuple, Union
+from typing import Any, Dict, Iterator, List, Optional, Sequence, Tuple, Union
 
-import aesara.gradient as tg
 import numpy as np
+import pytensor.gradient as tg
 
 from arviz import InferenceData
 from fastprogress.fastprogress import progress_bar
-from typing_extensions import TypeAlias
+from typing_extensions import Protocol, TypeAlias
 
 import pymc as pm
 
@@ -42,7 +41,7 @@ from pymc.model import Model, modelcontext
 from pymc.sampling.parallel import Draw, _cpu_count
 from pymc.sampling.population import _sample_population
 from pymc.stats.convergence import log_warning_stats, run_convergence_checks
-from pymc.step_methods import NUTS, CompoundStep, DEMetropolis
+from pymc.step_methods import NUTS, CompoundStep
 from pymc.step_methods.arraystep import BlockedStep, PopulationArrayStepShared
 from pymc.step_methods.hmc import quadpotential
 from pymc.util import (
@@ -59,13 +58,19 @@ sys.setrecursionlimit(10000)
 
 __all__ = [
     "sample",
-    "iter_sample",
     "init_nuts",
 ]
 
 Step: TypeAlias = Union[BlockedStep, CompoundStep]
 
 
+class SamplingIteratorCallback(Protocol):
+    """Signature of the callable that may be passed to `pm.sample(callable=...)`."""
+
+    def __call__(self, trace: BaseTrace, draw: Draw):
+        pass
+
+
 _log = logging.getLogger("pymc")
 
 
@@ -223,7 +228,7 @@ def sample(
     cores: Optional[int] = None,
     tune: int = 1000,
     progressbar: bool = True,
-    model=None,
+    model: Optional[Model] = None,
     random_seed: RandomState = None,
     discard_tuned_samples: bool = True,
     compute_convergence_checks: bool = True,
@@ -481,11 +486,23 @@ def sample(
         model.check_start_vals(ip)
         _check_start_shape(model, ip)
 
+    # Create trace backends for each chain
+    traces = [
+        _init_trace(
+            expected_length=draws + tune,
+            stats_dtypes=step.stats_dtypes,
+            chain_number=chain_number,
+            trace=trace,
+            model=model,
+        )
+        for chain_number in range(chains)
+    ]
+
     sample_args = {
         "draws": draws,
         "step": step,
         "start": initial_points,
-        "trace": trace,
+        "traces": traces,
         "chains": chains,
         "tune": tune,
         "progressbar": progressbar,
@@ -526,7 +543,7 @@ def sample(
         _log.info(f"Multiprocess sampling ({chains} chains in {cores} jobs)")
         _print_step_hierarchy(step)
         try:
-            mtrace = _mp_sample(**sample_args, **parallel_args)
+            _mp_sample(**sample_args, **parallel_args)
         except pickle.PickleError:
             _log.warning("Could not pickle model, sampling singlethreaded.")
             _log.debug("Pickling error:", exc_info=True)
@@ -539,38 +556,23 @@ def sample(
             parallel = False
     if not parallel:
         if has_population_samplers:
-            has_demcmc = np.any(
-                [
-                    isinstance(m, DEMetropolis)
-                    for m in (step.methods if isinstance(step, CompoundStep) else [step])
-                ]
-            )
             _log.info(f"Population sampling ({chains} chains)")
-
-            initial_point_model_size = sum(initial_points[0][n.name].size for n in model.value_vars)
-
-            if has_demcmc and chains < 3:
-                raise ValueError(
-                    "DEMetropolis requires at least 3 chains. "
-                    "For this {}-dimensional model you should use ≥{} chains".format(
-                        initial_point_model_size, initial_point_model_size + 1
-                    )
-                )
-            if has_demcmc and chains <= initial_point_model_size:
-                warnings.warn(
-                    "DEMetropolis should be used with more chains than dimensions! "
-                    "(The model has {} dimensions.)".format(initial_point_model_size),
-                    UserWarning,
-                    stacklevel=2,
-                )
             _print_step_hierarchy(step)
-            mtrace = _sample_population(parallelize=cores > 1, **sample_args)
+            _sample_population(initial_points=initial_points, parallelize=cores > 1, **sample_args)
         else:
             _log.info(f"Sequential sampling ({chains} chains in 1 job)")
             _print_step_hierarchy(step)
-            mtrace = _sample_many(**sample_args)
+            _sample_many(**sample_args)
 
     t_sampling = time.time() - t_start
+
+    # Wrap chain traces in a MultiTrace
+    if discard_tuned_samples:
+        traces, length = _choose_chains(traces, tune)
+    else:
+        traces, length = _choose_chains(traces, 0)
+    mtrace = MultiTrace(traces)[:length]
+
     # count the number of tune/draw iterations that happened
     # ideally via the "tune" statistic, but not all samplers record it!
     if "tune" in mtrace.stat_names:
@@ -604,7 +606,7 @@ def sample(
 
     idata = None
     if compute_convergence_checks or return_inferencedata:
-        ikwargs = dict(model=model, save_warmup=not discard_tuned_samples)
+        ikwargs: Dict[str, Any] = dict(model=model, save_warmup=not discard_tuned_samples)
         if idata_kwargs:
             ikwargs.update(idata_kwargs)
         idata = pm.to_inference_data(mtrace, **ikwargs)
@@ -654,14 +656,16 @@ def _check_start_shape(model, start: PointType):
 
 
 def _sample_many(
+    *,
     draws: int,
     chains: int,
+    traces: Sequence[BaseTrace],
     start: Sequence[PointType],
     random_seed: Optional[Sequence[RandomSeed]],
-    step,
-    callback=None,
+    step: Step,
+    callback: Optional[SamplingIteratorCallback] = None,
     **kwargs,
-) -> MultiTrace:
+):
     """Samples all chains sequentially.
 
     Parameters
@@ -676,35 +680,19 @@ def _sample_many(
         A list of seeds, one for each chain
     step: function
         Step function
-
-    Returns
-    -------
-    mtrace: MultiTrace
-        Contains samples of all chains
     """
-    traces: List[BaseTrace] = []
     for i in range(chains):
-        trace = _sample(
+        _sample(
             draws=draws,
             chain=i,
             start=start[i],
             step=step,
+            trace=traces[i],
             random_seed=None if random_seed is None else random_seed[i],
             callback=callback,
             **kwargs,
         )
-        if trace is None:
-            if len(traces) == 0:
-                raise ValueError("Sampling stopped before a sample was created.")
-            else:
-                break
-        elif len(trace) < draws:
-            if len(traces) == 0:
-                traces.append(trace)
-            break
-        else:
-            traces.append(trace)
-    return MultiTrace(traces)
+    return
 
 
 def _sample(
@@ -714,13 +702,13 @@ def _sample(
     random_seed: RandomSeed,
     start: PointType,
     draws: int,
-    step=None,
-    trace: Optional[BaseTrace] = None,
+    step: Step,
+    trace: BaseTrace,
     tune: int,
     model: Optional[Model] = None,
     callback=None,
     **kwargs,
-) -> BaseTrace:
+) -> None:
     """Main iteration for singleprocess sampling.
 
     Multiple step methods are supported via compound step methods.
@@ -741,23 +729,23 @@ def _sample(
     step : function
         Step function
     trace : backend, optional
-        A backend instance or None.
-        If None, the NDArray backend is used.
+        A backend instance.
     tune : int
         Number of iterations to tune.
     model : Model (optional if in ``with`` context)
-
-    Returns
-    -------
-    strace : BaseTrace
-        A ``BaseTrace`` object that contains the samples for this chain.
     """
     skip_first = kwargs.get("skip_first", 0)
 
-    trace = copy(trace)
-
     sampling_gen = _iter_sample(
-        draws, step, start, trace, chain, tune, model, random_seed, callback
+        draws=draws,
+        step=step,
+        start=start,
+        trace=trace,
+        chain=chain,
+        tune=tune,
+        model=model,
+        random_seed=random_seed,
+        callback=callback,
     )
     _pbar_data = {"chain": chain, "divergences": 0}
     _desc = "Sampling chain {chain:d}, {divergences:,d} divergences"
@@ -767,87 +755,27 @@ def _sample(
     else:
         sampling = sampling_gen
     try:
-        strace = None
-        for it, (strace, diverging) in enumerate(sampling):
+        for it, diverging in enumerate(sampling):
             if it >= skip_first and diverging:
                 _pbar_data["divergences"] += 1
                 if progressbar:
                     sampling.comment = _desc.format(**_pbar_data)
     except KeyboardInterrupt:
         pass
-    if strace is None:
-        raise Exception("KeyboardInterrupt happened before the base trace was created.")
-    return strace
 
 
-def iter_sample(
+def _iter_sample(
+    *,
     draws: int,
-    step,
+    step: Step,
     start: PointType,
-    trace=None,
+    trace: BaseTrace,
     chain: int = 0,
     tune: int = 0,
     model: Optional[Model] = None,
     random_seed: RandomSeed = None,
-    callback=None,
-) -> Iterator[MultiTrace]:
-    """Generate a trace on each iteration using the given step method.
-
-    Multiple step methods ared supported via compound step methods.  Returns the
-    amount of time taken.
-
-    Parameters
-    ----------
-    draws : int
-        The number of samples to draw
-    step : function
-        Step function
-    start : dict
-        Starting point in parameter space (or partial point).
-    trace : backend or list
-        This should be a backend instance, or a list of variables to track.
-        If None or a list of variables, the NDArray backend is used.
-    chain : int, optional
-        Chain number used to store sample in backend.
-    tune : int, optional
-        Number of iterations to tune (defaults to 0).
-    model : Model (optional if in ``with`` context)
-    random_seed : single random seed, optional
-    callback :
-        A function which gets called for every sample from the trace of a chain. The function is
-        called with the trace and the current draw and will contain all samples for a single trace.
-        the ``draw.chain`` argument can be used to determine which of the active chains the sample
-        is drawn from.
-        Sampling can be interrupted by throwing a ``KeyboardInterrupt`` in the callback.
-
-    Yields
-    ------
-    trace : MultiTrace
-        Contains all samples up to the current iteration
-
-    Examples
-    --------
-    ::
-
-        for trace in iter_sample(500, step):
-            ...
-    """
-    sampling = _iter_sample(draws, step, start, trace, chain, tune, model, random_seed, callback)
-    for i, (strace, _) in enumerate(sampling):
-        yield MultiTrace([strace[: i + 1]])
-
-
-def _iter_sample(
-    draws: int,
-    step,
-    start: PointType,
-    trace: Optional[BaseTrace] = None,
-    chain: int = 0,
-    tune: int = 0,
-    model=None,
-    random_seed: RandomSeed = None,
-    callback=None,
-) -> Iterator[Tuple[BaseTrace, bool]]:
+    callback: Optional[SamplingIteratorCallback] = None,
+) -> Iterator[bool]:
     """Generator for sampling one chain. (Used in singleprocess sampling.)
 
     Parameters
@@ -859,9 +787,8 @@ def _iter_sample(
     start : dict
         Starting point in parameter space (or partial point).
         Must contain numeric (transformed) initial values for all (transformed) free variables.
-    trace : backend, optional
-        A backend instance or None.
-        If None, the NDArray backend is used.
+    trace : backend
+        A backend instance.
     chain : int, optional
         Chain number used to store sample in backend.
     tune : int, optional
@@ -871,8 +798,6 @@ def _iter_sample(
 
     Yields
     ------
-    strace : BaseTrace
-        The trace object containing the samples for this chain
     diverging : bool
         Indicates if the draw is divergent. Only available with some samplers.
     """
@@ -885,27 +810,13 @@ def _iter_sample(
     if random_seed is not None:
         np.random.seed(random_seed)
 
-    try:
-        step = CompoundStep(step)
-    except TypeError:
-        pass
-
     point = start
 
-    strace: BaseTrace = _init_trace(
-        expected_length=draws + tune,
-        stats_dtypes=step.stats_dtypes,
-        chain_number=chain,
-        trace=trace,
-        model=model,
-    )
-
     try:
         step.tune = bool(tune)
         if hasattr(step, "reset_tuning"):
             step.reset_tuning()
         for i in range(draws):
-            stats = None
             diverging = False
 
             if i == 0 and hasattr(step, "iter_count"):
@@ -913,27 +824,28 @@ def _iter_sample(
             if i == tune:
                 step.stop_tuning()
             point, stats = step.step(point)
-            strace.record(point, stats)
+            trace.record(point, stats)
             log_warning_stats(stats)
-            diverging = i > tune and stats and stats[0].get("diverging")
+            diverging = i > tune and len(stats) > 0 and (stats[0].get("diverging") == True)
             if callback is not None:
                 callback(
-                    trace=strace,
+                    trace=trace,
                     draw=Draw(chain, i == draws, i, i < tune, stats, point),
                 )
 
-            yield strace, diverging
+            yield diverging
     except KeyboardInterrupt:
-        strace.close()
+        trace.close()
         raise
     except BaseException:
-        strace.close()
+        trace.close()
         raise
     else:
-        strace.close()
+        trace.close()
 
 
 def _mp_sample(
+    *,
     draws: int,
     tune: int,
     step,
@@ -942,13 +854,12 @@ def _mp_sample(
     random_seed: Sequence[RandomSeed],
     start: Sequence[PointType],
     progressbar: bool = True,
-    trace: Optional[BaseTrace] = None,
-    model=None,
-    callback=None,
-    discard_tuned_samples: bool = True,
+    traces: Sequence[BaseTrace],
+    model: Optional[Model] = None,
+    callback: Optional[SamplingIteratorCallback] = None,
     mp_ctx=None,
     **kwargs,
-) -> MultiTrace:
+) -> None:
     """Main iteration for multiprocess sampling.
 
     Parameters
@@ -974,34 +885,18 @@ def _mp_sample(
         A backend instance, or None.
         If None, the NDArray backend is used.
     model : Model (optional if in ``with`` context)
-    callback : Callable
+    callback
         A function which gets called for every sample from the trace of a chain. The function is
         called with the trace and the current draw and will contain all samples for a single trace.
         the ``draw.chain`` argument can be used to determine which of the active chains the sample
         is drawn from.
         Sampling can be interrupted by throwing a ``KeyboardInterrupt`` in the callback.
-
-    Returns
-    -------
-    mtrace : pymc.backends.base.MultiTrace
-        A ``MultiTrace`` object that contains the samples for all chains.
     """
     import pymc.sampling.parallel as ps
 
     # We did draws += tune in pm.sample
     draws -= tune
 
-    traces = [
-        _init_trace(
-            expected_length=draws + tune,
-            stats_dtypes=step.stats_dtypes,
-            chain_number=chain_number,
-            trace=trace,
-            model=model,
-        )
-        for chain_number in range(chains)
-    ]
-
     sampler = ps.ParallelSampler(
         draws=draws,
         tune=tune,
@@ -1024,7 +919,7 @@ def _mp_sample(
                         strace.close()
 
                     if callback is not None:
-                        callback(trace=trace, draw=draw)
+                        callback(trace=strace, draw=draw)
 
         except ps.ParallelSamplingError as error:
             strace = traces[error._chain]
@@ -1034,13 +929,8 @@ def _mp_sample(
             multitrace = MultiTrace(traces)
             multitrace._report._log_summary()
             raise
-        return MultiTrace(traces)
     except KeyboardInterrupt:
-        if discard_tuned_samples:
-            traces, length = _choose_chains(traces, tune)
-        else:
-            traces, length = _choose_chains(traces, 0)
-        return MultiTrace(traces)[:length]
+        pass
     finally:
         for strace in traces:
             strace.close()
@@ -1105,7 +995,7 @@ def init_nuts(
     init: str = "auto",
     chains: int = 1,
     n_init: int = 500_000,
-    model=None,
+    model: Optional[Model] = None,
     random_seed: RandomSeed = None,
     progressbar=True,
     jitter_max_retries: int = 10,
