@@ -124,25 +124,6 @@ class TestMultiTrace(bf.ModelBackendSetupTestCase):
             base.MultiTrace([self.strace0, self.strace1])
 
 
-class TestMultiTrace_add_remove_values(bf.ModelBackendSampledTestCase):
-    name = None
-    backend = ndarray.NDArray
-    shape = ()
-
-    def test_add_values(self):
-        mtrace = self.mtrace
-        orig_varnames = list(mtrace.varnames)
-        name = "new_var"
-        vals = mtrace[orig_varnames[0]]
-        mtrace.add_values({name: vals})
-        assert len(orig_varnames) == len(mtrace.varnames) - 1
-        assert name in mtrace.varnames
-        assert np.all(mtrace[orig_varnames[0]] == mtrace[name])
-        mtrace.remove_values(name)
-        assert len(orig_varnames) == len(mtrace.varnames)
-        assert name not in mtrace.varnames
-
-
 class TestSqueezeCat:
     def setup_method(self):
         self.x = np.arange(10)
