@@ -14,23 +14,23 @@
 
 import functools as ft
 
-import aesara
-import aesara.tensor as at
 import numpy as np
 import numpy.testing as npt
+import pytensor
+import pytensor.tensor as at
 import pytest
 import scipy.special as sp
 import scipy.stats as st
 
-from aeppl.logprob import ParameterValueError
-from aesara.compile.mode import Mode
+from pytensor.compile.mode import Mode
 
 import pymc as pm
 
-from pymc.aesaraf import floatX
 from pymc.distributions import logcdf, logp
-from pymc.distributions.continuous import get_tau_sigma, interpolated
+from pymc.distributions.continuous import Normal, get_tau_sigma, interpolated
 from pymc.distributions.dist_math import clipped_beta_rvs
+from pymc.logprob.utils import ParameterValueError
+from pymc.pytensorf import floatX
 from pymc.tests.distributions.util import (
     BaseTestDistributionRandom,
     Circ,
@@ -49,6 +49,7 @@ from pymc.tests.distributions.util import (
     seeded_scipy_distribution_builder,
 )
 from pymc.tests.helpers import select_by_precision
+from pymc.tests.logprob.utils import create_pytensor_params, scipy_logprob_tester
 
 try:
     from polyagamma import polyagamma_cdf, polyagamma_pdf, random_polyagamma
@@ -184,9 +185,11 @@ class TestMatchesScipy:
         )
         # Custom logp / logcdf check for invalid parameters
         invalid_dist = pm.Uniform.dist(lower=1, upper=0)
-        with aesara.config.change_flags(mode=Mode("py")):
-            assert logp(invalid_dist, np.array(0.5)).eval() == -np.inf
-            assert logcdf(invalid_dist, np.array(2.0)).eval() == -np.inf
+        with pytensor.config.change_flags(mode=Mode("py")):
+            with pytest.raises(ParameterValueError):
+                logp(invalid_dist, np.array(0.5)).eval()
+            with pytest.raises(ParameterValueError):
+                logcdf(invalid_dist, np.array(0.5)).eval()
 
     def test_triangular(self):
         check_logp(
@@ -206,19 +209,19 @@ class TestMatchesScipy:
 
         # Custom logp/logcdf check for values outside of domain
         valid_dist = pm.Triangular.dist(lower=0, upper=1, c=0.9, size=2)
-        with aesara.config.change_flags(mode=Mode("py")):
+        with pytensor.config.change_flags(mode=Mode("py")):
             assert np.all(logp(valid_dist, np.array([-1, 2])).eval() == -np.inf)
             assert np.all(logcdf(valid_dist, np.array([-1, 2])).eval() == [-np.inf, 0])
 
         # Custom logcdf check for invalid parameters.
         # Invalid logp checks for triangular are being done in aeppl
         invalid_dist = pm.Triangular.dist(lower=1, upper=0, c=0.1)
-        with aesara.config.change_flags(mode=Mode("py")):
+        with pytensor.config.change_flags(mode=Mode("py")):
             with pytest.raises(ParameterValueError):
                 logcdf(invalid_dist, 2).eval()
 
         invalid_dist = pm.Triangular.dist(lower=0, upper=1, c=2.0)
-        with aesara.config.change_flags(mode=Mode("py")):
+        with pytensor.config.change_flags(mode=Mode("py")):
             with pytest.raises(ParameterValueError):
                 logcdf(invalid_dist, 2).eval()
 
@@ -300,7 +303,7 @@ class TestMatchesScipy:
         )
 
     @pytest.mark.skipif(
-        condition=(aesara.config.floatX == "float32"),
+        condition=(pytensor.config.floatX == "float32"),
         reason="Fails on float32 due to numerical issues",
     )
     def test_chisquared_logcdf(self):
@@ -372,7 +375,7 @@ class TestMatchesScipy:
         )
 
     @pytest.mark.skipif(
-        condition=(aesara.config.floatX == "float32"),
+        condition=(pytensor.config.floatX == "float32"),
         reason="Fails on float32 due to numerical issues",
     )
     def test_beta_logcdf(self):
@@ -484,7 +487,7 @@ class TestMatchesScipy:
         )
 
     @pytest.mark.skipif(
-        condition=(aesara.config.floatX == "float32"),
+        condition=(pytensor.config.floatX == "float32"),
         reason="Fails on float32 due to numerical issues",
     )
     def test_studentt_logcdf(self):
@@ -548,7 +551,7 @@ class TestMatchesScipy:
         )
 
     @pytest.mark.skipif(
-        condition=(aesara.config.floatX == "float32"),
+        condition=(pytensor.config.floatX == "float32"),
         reason="Fails on float32 due to numerical issues",
     )
     def test_gamma_logcdf(self):
@@ -568,7 +571,7 @@ class TestMatchesScipy:
         )
 
     @pytest.mark.skipif(
-        condition=(aesara.config.floatX == "float32"),
+        condition=(pytensor.config.floatX == "float32"),
         reason="Fails on float32 due to numerical issues",
     )
     def test_inverse_gamma_logcdf(self):
@@ -580,7 +583,7 @@ class TestMatchesScipy:
         )
 
     @pytest.mark.skipif(
-        condition=(aesara.config.floatX == "float32"),
+        condition=(pytensor.config.floatX == "float32"),
         reason="Fails on float32 due to scaling issues",
     )
     def test_inverse_gamma_alt_params(self):
@@ -611,7 +614,7 @@ class TestMatchesScipy:
         )
 
     @pytest.mark.skipif(
-        condition=(aesara.config.floatX == "float32"),
+        condition=(pytensor.config.floatX == "float32"),
         reason="Fails on float32 due to numerical issues",
     )
     def test_weibull_logp(self):
@@ -623,7 +626,7 @@ class TestMatchesScipy:
         )
 
     @pytest.mark.skipif(
-        condition=(aesara.config.floatX == "float32"),
+        condition=(pytensor.config.floatX == "float32"),
         reason="Fails on float32 due to inf issues",
     )
     def test_weibull_logcdf(self):
@@ -688,7 +691,7 @@ class TestMatchesScipy:
             skip_paramdomain_inside_edge_test=True,  # Valid values are tested above
         )
 
-    @pytest.mark.skipif(condition=(aesara.config.floatX == "float32"), reason="Fails on float32")
+    @pytest.mark.skipif(condition=(pytensor.config.floatX == "float32"), reason="Fails on float32")
     def test_vonmises(self):
         check_logp(
             pm.VonMises,
@@ -739,7 +742,7 @@ class TestMatchesScipy:
         )
 
     @pytest.mark.skipif(
-        condition=(aesara.config.floatX == "float32"),
+        condition=(pytensor.config.floatX == "float32"),
         reason="Some combinations underflow to -inf in float32 in pymc version",
     )
     def test_rice(self):
@@ -749,7 +752,7 @@ class TestMatchesScipy:
             {"b": Rplus, "sigma": Rplusbig},
             lambda value, b, sigma: st.rice.logpdf(value, b=b, loc=0, scale=sigma),
         )
-        if aesara.config.floatX == "float32":
+        if pytensor.config.floatX == "float32":
             raise Exception("Flaky test: It passed this time, but XPASS is not allowed.")
 
     def test_rice_nu(self):
@@ -761,7 +764,7 @@ class TestMatchesScipy:
         )
 
     def test_moyal_logp(self):
-        # Using a custom domain, because the standard `R` domain undeflows with scipy in float64
+        # Using a custom domain, because the standard `R` domain underflows with scipy in float64
         value_domain = Domain([-np.inf, -1.5, -1, -0.01, 0.0, 0.01, 1, 1.5, np.inf])
         check_logp(
             pm.Moyal,
@@ -771,17 +774,20 @@ class TestMatchesScipy:
         )
 
     @pytest.mark.skipif(
-        condition=(aesara.config.floatX == "float32"),
+        condition=(pytensor.config.floatX == "float32"),
         reason="PyMC underflows earlier than scipy on float32",
     )
     def test_moyal_logcdf(self):
+        # SciPy has new (?) precision issues at {mu=-2.1, sigma=0.5, x=2.1}
+        # We circumvent it by skipping sigma=0.5:
+        rplusbig = Domain([0, 0.9, 0.99, 1, 1.5, 2, 20, np.inf])
         check_logcdf(
             pm.Moyal,
             R,
-            {"mu": R, "sigma": Rplusbig},
+            {"mu": R, "sigma": rplusbig},
             lambda value, mu, sigma: floatX(st.moyal.logcdf(value, mu, sigma)),
         )
-        if aesara.config.floatX == "float32":
+        if pytensor.config.floatX == "float32":
             raise Exception("Flaky test: It passed this time, but XPASS is not allowed.")
 
     def test_interpolated(self):
@@ -1645,6 +1651,19 @@ class TestAsymmetricLaplace(BaseTestDistributionRandom):
     ]
 
 
+class TestAsymmetricLaplaceQ(BaseTestDistributionRandom):
+    pymc_dist = pm.AsymmetricLaplace
+
+    pymc_dist_params = {"mu": 0.0, "b": 2.0, "q": 0.9}
+    expected_kappa = pymc_dist.get_kappa(None, pymc_dist_params["q"])
+    expected_rv_op_params = {
+        "b": pymc_dist_params["b"],
+        "kappa": expected_kappa,
+        "mu": pymc_dist_params["mu"],
+    }
+    checks_to_run = ["check_pymc_params_match_rv_op"]
+
+
 class TestExGaussian(BaseTestDistributionRandom):
     def exgaussian_rng_fn(self, mu, sigma, nu, size, normal_rng_fct, exponential_rng_fct):
         return normal_rng_fct(mu, sigma, size=size) + exponential_rng_fct(scale=nu, size=size)
@@ -2230,6 +2249,25 @@ class TestInterpolated(BaseTestDistributionRandom):
                 pymc_random(
                     TestedInterpolated,
                     {},
-                    extra_args={"rng": aesara.shared(rng)},
+                    extra_args={"rng": pytensor.shared(rng)},
                     ref_rand=ref_rand,
                 )
+
+
+class TestICDF:
+    @pytest.mark.parametrize(
+        "dist_params, obs, size",
+        [
+            ((0, 1), np.array([-0.5, 0, 0.3, 0.5, 1, 1.5], dtype=np.float64), ()),
+            ((-1, 20), np.array([-0.5, 0, 0.3, 0.5, 1, 1.5], dtype=np.float64), ()),
+            ((-1, 20), np.array([-0.5, 0, 0.3, 0.5, 1, 1.5], dtype=np.float64), (2, 3)),
+        ],
+    )
+    def test_normal_icdf(self, dist_params, obs, size):
+
+        dist_params_at, obs_at, size_at = create_pytensor_params(dist_params, obs, size)
+        dist_params = dict(zip(dist_params_at, dist_params))
+
+        x = Normal.dist(*dist_params_at, size=size_at)
+
+        scipy_logprob_tester(x, obs, dist_params, test_fn=st.norm.ppf, test="icdf")
