@@ -13,18 +13,20 @@
 #   limitations under the License.
 
 
-import aesara
-import aesara.tensor as at
+from typing import Union
+
 import numpy as np
+import pytensor
+import pytensor.tensor as at
 import pytest
 
-from aesara.tensor.var import TensorConstant
+from pytensor.tensor.var import TensorConstant
 
 import pymc as pm
 import pymc.distributions.transforms as tr
 
-from pymc.aesaraf import floatX, jacobian
 from pymc.distributions.logprob import _joint_logp
+from pymc.pytensorf import floatX, jacobian
 from pymc.tests.checks import close_to, close_to_logical
 from pymc.tests.distributions.util import (
     Circ,
@@ -40,9 +42,9 @@ from pymc.tests.distributions.util import (
 )
 from pymc.tests.helpers import SeededTest
 
-# some transforms (stick breaking) require additon of small slack in order to be numerically
+# some transforms (stick breaking) require addition of small slack in order to be numerically
 # stable. The minimal addable slack for float32 is higher thus we need to be less strict
-tol = 1e-7 if aesara.config.floatX == "float64" else 1e-6
+tol = 1e-7 if pytensor.config.floatX == "float64" else 1e-6
 
 
 def check_transform(transform, domain, constructor=at.dscalar, test=0, rv_var=None):
@@ -53,9 +55,9 @@ def check_transform(transform, domain, constructor=at.dscalar, test=0, rv_var=No
     rv_inputs = rv_var.owner.inputs if rv_var.owner else []
     # test forward and forward_val
     # FIXME: What's being tested here?  That the transformed graph can compile?
-    forward_f = aesara.function([x], transform.forward(x, *rv_inputs))
+    forward_f = pytensor.function([x], transform.forward(x, *rv_inputs))
     # test transform identity
-    identity_f = aesara.function(
+    identity_f = pytensor.function(
         [x], transform.backward(transform.forward(x, *rv_inputs), *rv_inputs)
     )
     for val in domain.vals:
@@ -72,7 +74,7 @@ def get_values(transform, domain=R, constructor=at.dscalar, test=0, rv_var=None)
     if rv_var is None:
         rv_var = x
     rv_inputs = rv_var.owner.inputs if rv_var.owner else []
-    f = aesara.function([x], transform.backward(x, *rv_inputs))
+    f = pytensor.function([x], transform.backward(x, *rv_inputs))
     return np.array([f(val) for val in domain.vals])
 
 
@@ -103,9 +105,9 @@ def check_jacobian_det(
         jac = at.log(at.abs(at.diag(jacobian(x, [y]))))
 
     # ljd = log jacobian det
-    actual_ljd = aesara.function([y], jac)
+    actual_ljd = pytensor.function([y], jac)
 
-    computed_ljd = aesara.function(
+    computed_ljd = pytensor.function(
         [y], at.as_tensor_variable(transform.log_jac_det(y, *rv_inputs)), on_unused_input="ignore"
     )
 
@@ -134,15 +136,23 @@ def test_simplex_accuracy():
     val = np.array([-30])
     x = at.dvector("x")
     x.tag.test_value = val
-    identity_f = aesara.function([x], tr.simplex.forward(x, tr.simplex.backward(x, x)))
+    identity_f = pytensor.function([x], tr.simplex.forward(x, tr.simplex.backward(x, x)))
     close_to(val, identity_f(val), tol)
 
 
 def test_sum_to_1():
-    check_vector_transform(tr.sum_to_1, Simplex(2))
-    check_vector_transform(tr.sum_to_1, Simplex(4))
+    check_vector_transform(tr.univariate_sum_to_1, Simplex(2))
+    check_vector_transform(tr.univariate_sum_to_1, Simplex(4))
 
-    check_jacobian_det(tr.sum_to_1, Vector(Unit, 2), at.dvector, np.array([0, 0]), lambda x: x[:-1])
+    with pytest.raises(ValueError, match=r"\(ndim_supp\) must not exceed 1"):
+        tr.SumTo1(2)
+
+    check_jacobian_det(
+        tr.univariate_sum_to_1, Vector(Unit, 2), at.dvector, np.array([0, 0]), lambda x: x[:-1]
+    )
+    check_jacobian_det(
+        tr.multivariate_sum_to_1, Vector(Unit, 2), at.dvector, np.array([0, 0]), lambda x: x[:-1]
+    )
 
 
 def test_log():
@@ -213,7 +223,7 @@ def test_interval():
 
 
 @pytest.mark.skipif(
-    aesara.config.floatX == "float32", reason="Test is designed for 64bit precision"
+    pytensor.config.floatX == "float32", reason="Test is designed for 64bit precision"
 )
 def test_interval_near_boundary():
     lb = -1.0
@@ -241,28 +251,36 @@ def test_circular():
 
 
 def test_ordered():
-    check_vector_transform(tr.ordered, SortedVector(6))
+    check_vector_transform(tr.univariate_ordered, SortedVector(6))
 
-    check_jacobian_det(tr.ordered, Vector(R, 2), at.dvector, np.array([0, 0]), elemwise=False)
+    with pytest.raises(ValueError, match=r"\(ndim_supp\) must not exceed 1"):
+        tr.Ordered(2)
 
-    vals = get_values(tr.ordered, Vector(R, 3), at.dvector, np.zeros(3))
+    check_jacobian_det(
+        tr.univariate_ordered, Vector(R, 2), at.dvector, np.array([0, 0]), elemwise=False
+    )
+    check_jacobian_det(
+        tr.multivariate_ordered, Vector(R, 2), at.dvector, np.array([0, 0]), elemwise=False
+    )
+
+    vals = get_values(tr.univariate_ordered, Vector(R, 3), at.dvector, np.zeros(3))
     close_to_logical(np.diff(vals) >= 0, True, tol)
 
 
 def test_chain_values():
-    chain_tranf = tr.Chain([tr.logodds, tr.ordered])
+    chain_tranf = tr.Chain([tr.logodds, tr.univariate_ordered])
     vals = get_values(chain_tranf, Vector(R, 5), at.dvector, np.zeros(5))
     close_to_logical(np.diff(vals) >= 0, True, tol)
 
 
 def test_chain_vector_transform():
-    chain_tranf = tr.Chain([tr.logodds, tr.ordered])
+    chain_tranf = tr.Chain([tr.logodds, tr.univariate_ordered])
     check_vector_transform(chain_tranf, UnitSortedVector(3))
 
 
 @pytest.mark.xfail(reason="Fails due to precision issue. Values just close to expected.")
 def test_chain_jacob_det():
-    chain_tranf = tr.Chain([tr.logodds, tr.ordered])
+    chain_tranf = tr.Chain([tr.logodds, tr.univariate_ordered])
     check_jacobian_det(chain_tranf, Vector(R, 4), at.dvector, np.zeros(4), elemwise=False)
 
 
@@ -327,7 +345,14 @@ class TestElementWiseLogp(SeededTest):
         jacob_det = transform.log_jac_det(test_array_transf, *x.owner.inputs)
         # Original distribution is univariate
         if x.owner.op.ndim_supp == 0:
-            assert model.logp(x, sum=False)[0].ndim == x.ndim == (jacob_det.ndim + 1)
+            tr_steps = getattr(transform, "transform_list", [transform])
+            transform_keeps_dim = any(
+                [isinstance(ts, Union[tr.SumTo1, tr.Ordered]) for ts in tr_steps]
+            )
+            if transform_keeps_dim:
+                assert model.logp(x, sum=False)[0].ndim == x.ndim == jacob_det.ndim
+            else:
+                assert model.logp(x, sum=False)[0].ndim == x.ndim == (jacob_det.ndim + 1)
         # Original distribution is multivariate
         else:
             assert model.logp(x, sum=False)[0].ndim == (x.ndim - 1) == jacob_det.ndim
@@ -449,7 +474,7 @@ class TestElementWiseLogp(SeededTest):
             {"mu": 0.0, "sigma": 1.0},
             size=3,
             initval=np.asarray([-1.0, 1.0, 4.0]),
-            transform=tr.ordered,
+            transform=tr.univariate_ordered,
         )
         self.check_vectortransform_elementwise_logp(model)
 
@@ -467,7 +492,7 @@ class TestElementWiseLogp(SeededTest):
             {"sigma": sigma},
             size=size,
             initval=initval,
-            transform=tr.Chain([tr.log, tr.ordered]),
+            transform=tr.Chain([tr.log, tr.univariate_ordered]),
         )
         self.check_vectortransform_elementwise_logp(model)
 
@@ -479,7 +504,7 @@ class TestElementWiseLogp(SeededTest):
             {"lam": lam},
             size=size,
             initval=initval,
-            transform=tr.Chain([tr.log, tr.ordered]),
+            transform=tr.Chain([tr.log, tr.univariate_ordered]),
         )
         self.check_vectortransform_elementwise_logp(model)
 
@@ -501,7 +526,7 @@ class TestElementWiseLogp(SeededTest):
             {"alpha": a, "beta": b},
             size=size,
             initval=initval,
-            transform=tr.Chain([tr.logodds, tr.ordered]),
+            transform=tr.Chain([tr.logodds, tr.univariate_ordered]),
         )
         self.check_vectortransform_elementwise_logp(model)
 
@@ -524,7 +549,7 @@ class TestElementWiseLogp(SeededTest):
             {"lower": lower, "upper": upper},
             size=size,
             initval=initval,
-            transform=tr.Chain([interval, tr.ordered]),
+            transform=tr.Chain([interval, tr.univariate_ordered]),
         )
         self.check_vectortransform_elementwise_logp(model)
 
@@ -536,7 +561,7 @@ class TestElementWiseLogp(SeededTest):
             {"mu": mu, "kappa": kappa},
             size=size,
             initval=initval,
-            transform=tr.Chain([tr.circular, tr.ordered]),
+            transform=tr.Chain([tr.circular, tr.univariate_ordered]),
         )
         self.check_vectortransform_elementwise_logp(model)
 
@@ -545,7 +570,7 @@ class TestElementWiseLogp(SeededTest):
         [
             (0.0, 1.0, (2,), tr.simplex),
             (0.5, 5.5, (2, 3), tr.simplex),
-            (np.zeros(3), np.ones(3), (4, 3), tr.Chain([tr.sum_to_1, tr.logodds])),
+            (np.zeros(3), np.ones(3), (4, 3), tr.Chain([tr.univariate_sum_to_1, tr.logodds])),
         ],
     )
     def test_uniform_other(self, lower, upper, size, transform):
@@ -569,7 +594,11 @@ class TestElementWiseLogp(SeededTest):
     def test_mvnormal_ordered(self, mu, cov, size, shape):
         initval = np.sort(np.random.randn(*shape))
         model = self.build_model(
-            pm.MvNormal, {"mu": mu, "cov": cov}, size=size, initval=initval, transform=tr.ordered
+            pm.MvNormal,
+            {"mu": mu, "cov": cov},
+            size=size,
+            initval=initval,
+            transform=tr.multivariate_ordered,
         )
         self.check_vectortransform_elementwise_logp(model)
 
@@ -598,3 +627,95 @@ def test_discrete_trafo():
         with pytest.raises(ValueError) as err:
             pm.Binomial("a", n=5, p=0.5, transform="log")
         err.match("Transformations for discrete distributions")
+
+
+def test_2d_univariate_ordered():
+    with pm.Model() as model:
+        x_1d = pm.Normal(
+            "x_1d",
+            mu=[-3, -1, 1, 2],
+            sigma=1,
+            size=(4,),
+            transform=tr.univariate_ordered,
+        )
+        x_2d = pm.Normal(
+            "x_2d",
+            mu=[-3, -1, 1, 2],
+            sigma=1,
+            size=(10, 4),
+            transform=tr.univariate_ordered,
+        )
+
+    log_p = model.compile_logp(sum=False)(
+        {"x_1d_ordered__": np.zeros((4,)), "x_2d_ordered__": np.zeros((10, 4))}
+    )
+    np.testing.assert_allclose(np.tile(log_p[0], (10, 1)), log_p[1])
+
+
+def test_2d_multivariate_ordered():
+    with pm.Model() as model:
+        x_1d = pm.MvNormal(
+            "x_1d",
+            mu=[-1, 1],
+            cov=np.eye(2),
+            initval=[-1, 1],
+            transform=tr.multivariate_ordered,
+        )
+        x_2d = pm.MvNormal(
+            "x_2d",
+            mu=[-1, 1],
+            cov=np.eye(2),
+            size=2,
+            initval=[[-1, 1], [-1, 1]],
+            transform=tr.multivariate_ordered,
+        )
+
+    log_p = model.compile_logp(sum=False)(
+        {"x_1d_ordered__": np.zeros((2,)), "x_2d_ordered__": np.zeros((2, 2))}
+    )
+    np.testing.assert_allclose(log_p[0], log_p[1])
+
+
+def test_2d_univariate_sum_to_1():
+    with pm.Model() as model:
+        x_1d = pm.Normal(
+            "x_1d",
+            mu=[-3, -1, 1, 2],
+            sigma=1,
+            size=(4,),
+            transform=tr.univariate_sum_to_1,
+        )
+        x_2d = pm.Normal(
+            "x_2d",
+            mu=[-3, -1, 1, 2],
+            sigma=1,
+            size=(10, 4),
+            transform=tr.univariate_sum_to_1,
+        )
+
+    log_p = model.compile_logp(sum=False)(
+        {"x_1d_sumto1__": np.zeros(3), "x_2d_sumto1__": np.zeros((10, 3))}
+    )
+    np.testing.assert_allclose(np.tile(log_p[0], (10, 1)), log_p[1])
+
+
+def test_2d_multivariate_sum_to_1():
+    with pm.Model() as model:
+        x_1d = pm.MvNormal(
+            "x_1d",
+            mu=[-1, 1],
+            cov=np.eye(2),
+            transform=tr.multivariate_sum_to_1,
+        )
+        x_2d = pm.MvNormal(
+            "x_2d",
+            mu=[-1, 1],
+            cov=np.eye(2),
+            size=2,
+            transform=tr.multivariate_sum_to_1,
+        )
+
+    log_p = model.compile_logp(sum=False)(
+        {"x_1d_sumto1__": np.zeros(1), "x_2d_sumto1__": np.zeros((2, 1))}
+    )
+    np.testing.assert_allclose(log_p[0], log_p[1])
