@@ -1,12 +1,10 @@
-import aesara
-import aesara.tensor as at
 import numpy as np
+import pytensor
+import pytensor.tensor as at
 import pytest
 import scipy
 
-from aeppl.logprob import ParameterValueError, _icdf
-from aeppl.transforms import IntervalTransform
-from aesara.tensor.random.basic import GeometricRV, NormalRV
+from pytensor.tensor.random.basic import GeometricRV, NormalRV
 
 from pymc import Censored, Model, draw, find_MAP, logp
 from pymc.distributions.continuous import Exponential, TruncatedNormalRV
@@ -14,6 +12,9 @@ from pymc.distributions.shape_utils import change_dist_size
 from pymc.distributions.transforms import _default_transform
 from pymc.distributions.truncated import Truncated, TruncatedRV, _truncated
 from pymc.exceptions import TruncationError
+from pymc.logprob.abstract import _icdf
+from pymc.logprob.transforms import IntervalTransform
+from pymc.logprob.utils import ParameterValueError
 from pymc.tests.distributions.util import assert_moment_is_expected
 
 
@@ -55,7 +56,7 @@ def _icdf_not_implemented(*args, **kwargs):
 
 @pytest.mark.parametrize("shape_info", ("shape", "dims", "observed"))
 def test_truncation_specialized_op(shape_info):
-    rng = aesara.shared(np.random.default_rng())
+    rng = pytensor.shared(np.random.default_rng())
     x = at.random.normal(0, 10, rng=rng, name="x")
 
     with Model(coords={"dim": range(100)}) as m:
@@ -96,7 +97,7 @@ def test_truncation_continuous_random(op_type, lower, upper):
 
     xt = Truncated.dist(x, lower=lower, upper=upper)
     assert isinstance(xt.owner.op, TruncatedRV)
-    assert xt.type == x.type
+    assert xt.type.dtype == x.type.dtype
 
     xt_draws = draw(xt, draws=5)
     assert np.all(xt_draws >= lower)
@@ -136,7 +137,7 @@ def test_truncation_continuous_logp(op_type, lower, upper):
     assert isinstance(xt.owner.op, TruncatedRV)
 
     xt_vv = xt.clone()
-    xt_logp_fn = aesara.function([xt_vv], logp(xt, xt_vv))
+    xt_logp_fn = pytensor.function([xt_vv], logp(xt, xt_vv))
 
     ref_xt = scipy.stats.truncnorm(
         (lower - loc) / scale,
@@ -161,7 +162,7 @@ def test_truncation_discrete_random(op_type, lower, upper):
     x = geometric_op(p, name="x", size=500)
     xt = Truncated.dist(x, lower=lower, upper=upper)
     assert isinstance(xt.owner.op, TruncatedRV)
-    assert xt.type == x.type
+    assert xt.type.dtype == x.type.dtype
 
     xt_draws = draw(xt)
     assert np.all(xt_draws >= lower)
@@ -198,7 +199,7 @@ def test_truncation_discrete_logp(op_type, lower, upper):
     assert isinstance(xt.owner.op, TruncatedRV)
 
     xt_vv = xt.clone()
-    xt_logp_fn = aesara.function([xt_vv], logp(xt, xt_vv))
+    xt_logp_fn = pytensor.function([xt_vv], logp(xt, xt_vv))
 
     ref_xt = scipy.stats.geom(p)
     log_norm = np.log(ref_xt.cdf(upper) - ref_xt.cdf(lower - 1))
