@@ -11,10 +11,10 @@
 #   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
-import aesara.tensor as at
 import arviz as az
 import numpy as np
 import numpy.testing as npt
+import pytensor.tensor as at
 
 from scipy import stats
 
