@@ -16,14 +16,14 @@ import logging
 import sys
 import warnings
 
-import aesara.tensor as at
 import numpy as np
+import pytensor.tensor as at
 import pytest
 
 import pymc as pm
 
-from pymc.aesaraf import floatX
 from pymc.exceptions import SamplingError
+from pymc.pytensorf import floatX
 from pymc.step_methods.hmc import NUTS
 from pymc.tests import sampler_fixtures as sf
 from pymc.tests.helpers import RVsAssignmentStepsTester, StepMethodTester
@@ -167,7 +167,7 @@ class TestNutsCheckTrace:
         for varname in trace.stat_names:
             if varname == "warning":
                 # Warnings don't squeeze reliably.
-                # But once we stop squeezing alltogether that's going to be OK.
+                # But once we stop squeezing altogether that's going to be OK.
                 # See https://github.com/pymc-devs/pymc/issues/6207
                 continue
             assert trace.get_sampler_stats(varname).shape == (10,)
