@@ -17,24 +17,23 @@ import traceback
 import unittest
 import warnings
 
-import aesara
-import aesara.sparse as sparse
-import aesara.tensor as at
 import arviz as az
 import cloudpickle
 import numpy as np
 import numpy.ma as ma
 import numpy.testing as npt
+import pytensor
+import pytensor.sparse as sparse
+import pytensor.tensor as at
 import pytest
 import scipy.sparse as sps
 import scipy.stats as st
 
-from aeppl.transforms import IntervalTransform
-from aesara.graph import graph_inputs
-from aesara.tensor import TensorVariable
-from aesara.tensor.random.op import RandomVariable
-from aesara.tensor.sharedvar import ScalarSharedVariable
-from aesara.tensor.var import TensorConstant
+from pytensor.graph import graph_inputs
+from pytensor.tensor import TensorVariable
+from pytensor.tensor.random.op import RandomVariable
+from pytensor.tensor.sharedvar import ScalarSharedVariable
+from pytensor.tensor.var import TensorConstant
 
 import pymc as pm
 
@@ -44,6 +43,7 @@ from pymc.distributions import Normal, transforms
 from pymc.distributions.logprob import _joint_logp
 from pymc.distributions.transforms import log
 from pymc.exceptions import ImputationWarning, ShapeError, ShapeWarning
+from pymc.logprob.transforms import IntervalTransform
 from pymc.model import Point, ValueGradFunction, modelcontext
 from pymc.tests.helpers import SeededTest
 from pymc.tests.models import simple_model
@@ -211,13 +211,13 @@ class TestObserved:
 
     def test_observed_type(self):
         X_ = pm.floatX(np.random.randn(100, 5))
-        X = pm.floatX(aesara.shared(X_))
+        X = pm.floatX(pytensor.shared(X_))
         with pm.Model():
             x1 = pm.Normal("x1", observed=X_)
             x2 = pm.Normal("x2", observed=X)
 
-        assert x1.type == X.type
-        assert x2.type == X.type
+        assert x1.type.dtype == X.type.dtype
+        assert x2.type.dtype == X.type.dtype
 
 
 def test_duplicate_vars():
@@ -356,6 +356,9 @@ class TestValueGradFunction(unittest.TestCase):
 
         assert m["x2_missing"].type == gf._extra_vars_shared["x2_missing"].type
 
+        # The dtype of the merged observed/missing deterministic should match the RV dtype
+        assert m.deterministics[0].type.dtype == x2.type.dtype
+
         pnt = m.initial_point(random_seed=None).copy()
         del pnt["x2_missing"]
 
@@ -364,10 +367,10 @@ class TestValueGradFunction(unittest.TestCase):
         # Assert that all the elements of res are equal
         assert res[1:] == res[:-1]
 
-    def test_aesara_switch_broadcast_edge_cases_1(self):
+    def test_pytensor_switch_broadcast_edge_cases_1(self):
         # Tests against two subtle issues related to a previous bug in Theano
         # where `tt.switch` would not always broadcast tensors with single
-        # values https://github.com/pymc-devs/aesara/issues/270
+        # values https://github.com/pymc-devs/pytensor/issues/270
 
         # Known issue 1: https://github.com/pymc-devs/pymc/issues/4389
         data = pm.floatX(np.zeros(10))
@@ -380,7 +383,7 @@ class TestValueGradFunction(unittest.TestCase):
             np.log(0.5) * 10,
         )
 
-    def test_aesara_switch_broadcast_edge_cases_2(self):
+    def test_pytensor_switch_broadcast_edge_cases_2(self):
         # Known issue 2: https://github.com/pymc-devs/pymc/issues/4417
         # fmt: off
         data = np.array([
@@ -401,7 +404,7 @@ def test_multiple_observed_rv():
     y2_data = np.random.randn(100)
     with pm.Model() as model:
         mu = pm.Normal("mu")
-        x = pm.DensityDist(  # pylint: disable=unused-variable
+        x = pm.CustomDist(  # pylint: disable=unused-variable
             "x", mu, logp=lambda value, mu: pm.Normal.logp(value, mu, 1.0), observed=0.1
         )
     assert not model["x"] == model["mu"]
@@ -414,7 +417,7 @@ def test_tempered_logp_dlogp():
     with pm.Model() as model:
         pm.Normal("x")
         pm.Normal("y", observed=1)
-        pm.Potential("z", at.constant(-1.0, dtype=aesara.config.floatX))
+        pm.Potential("z", at.constant(-1.0, dtype=pytensor.config.floatX))
 
     func = model.logp_dlogp_function()
     func.set_extra_values({})
@@ -523,7 +526,7 @@ def test_make_obs_var():
     Check returned values for `data` given known inputs to `as_tensor()`.
 
     Note that ndarrays should return a TensorConstant and sparse inputs
-    should return a Sparse Aesara object.
+    should return a Sparse PyTensor object.
     """
     # Create the various inputs to the function
     input_name = "testing_inputs"
@@ -574,14 +577,14 @@ def test_initial_point():
         a = pm.Uniform("a")
         x = pm.Normal("x", a)
 
-    b_initval = np.array(0.3, dtype=aesara.config.floatX)
+    b_initval = np.array(0.3, dtype=pytensor.config.floatX)
 
     with pytest.warns(FutureWarning), model:
         b = pm.Uniform("b", testval=b_initval)
 
     b_initval_trans = model.rvs_to_transforms[b].forward(b_initval, *b.owner.inputs).eval()
 
-    y_initval = np.array(-2.4, dtype=aesara.config.floatX)
+    y_initval = np.array(-2.4, dtype=pytensor.config.floatX)
 
     with model:
         y = pm.Normal("y", initval=y_initval)
@@ -812,7 +815,7 @@ def test_add_coord_mutable_kwarg():
 
 
 def test_set_dim():
-    """Test the concious re-sizing of dims created through add_coord()."""
+    """Test the conscious re-sizing of dims created through add_coord()."""
     with pm.Model() as pmodel:
         pmodel.add_coord("fdim", mutable=False, length=1)
         pmodel.add_coord("mdim", mutable=True, length=2)
@@ -844,6 +847,30 @@ def test_set_dim_with_coords():
     assert pmodel.coords["mdim"] == ("A", "B", "C")
 
 
+def test_add_named_variable_checks_dim_name():
+    with pm.Model() as pmodel:
+        rv = pm.Normal.dist(mu=[1, 2])
+
+        # Checks that vars are named
+        with pytest.raises(ValueError, match="is unnamed"):
+            pmodel.add_named_variable(rv)
+        rv.name = "nomnom"
+
+        # Coords must be available already
+        with pytest.raises(ValueError, match="not specified in `coords`"):
+            pmodel.add_named_variable(rv, dims="nomnom")
+        pmodel.add_coord("nomnom", [1, 2])
+
+        # No name collisions
+        with pytest.raises(ValueError, match="same name as"):
+            pmodel.add_named_variable(rv, dims="nomnom")
+
+        # This should work (regression test against #6335)
+        rv2 = rv[:, None]
+        rv2.name = "yumyum"
+        pmodel.add_named_variable(rv2, dims=("nomnom", None))
+
+
 def test_set_data_indirect_resize():
     with pm.Model() as pmodel:
         pmodel.add_coord("mdim", mutable=True, length=2)
@@ -911,7 +938,7 @@ def test_set_data_constant_shape_error():
         pmodel.add_coord("weekday", length=x.shape[0])
         pm.MutableData("y", np.arange(7), dims="weekday")
 
-    msg = "because the dimension was initialized from 'x' which is not a shared variable"
+    msg = "because the dimension length is tied to a TensorConstant"
     with pytest.raises(ShapeError, match=msg):
         pmodel.set_data("y", np.arange(10))
 
@@ -1034,11 +1061,11 @@ def test_compile_fn():
     np.testing.assert_allclose(result_compute, result_expect)
 
 
-def test_model_aesara_config():
-    assert aesara.config.mode != "JAX"
-    with pm.Model(aesara_config=dict(mode="JAX")) as model:
-        assert aesara.config.mode == "JAX"
-    assert aesara.config.mode != "JAX"
+def test_model_pytensor_config():
+    assert pytensor.config.mode != "JAX"
+    with pm.Model(pytensor_config=dict(mode="JAX")) as model:
+        assert pytensor.config.mode == "JAX"
+    assert pytensor.config.mode != "JAX"
 
 
 def test_model_parent_set_programmatically():
@@ -1057,7 +1084,7 @@ class TestModelContext:
 
         This test creates two threads that attempt to construct two
         unrelated models at the same time.
-        For repeatable testing, the two threads are syncronised such
+        For repeatable testing, the two threads are synchronised such
         that thread A enters the context manager first, then B,
         then A attempts to declare a variable while B is still in the context manager.
         """
@@ -1430,7 +1457,7 @@ class TestShared(SeededTest):
     def test_deterministic(self):
         with pm.Model() as model:
             data_values = np.array([0.5, 0.4, 5, 2])
-            X = aesara.shared(np.asarray(data_values, dtype=aesara.config.floatX), borrow=True)
+            X = pytensor.shared(np.asarray(data_values, dtype=pytensor.config.floatX), borrow=True)
             pm.Normal("y", 0, 1, observed=X)
             assert np.all(
                 np.isclose(model.compile_logp(sum=False)({}), st.norm().logpdf(data_values))
@@ -1449,7 +1476,7 @@ def test_tag_future_warning_model():
         x.tag.test_value = 0
         assert not isinstance(x.tag, _FutureWarningValidatingScratchpad)
 
-        # Test that model changes the tag type, but copies exsiting contents
+        # Test that model changes the tag type, but copies existing contents
         x = model.register_rv(x, name="x", transform=log)
         assert isinstance(x.tag, _FutureWarningValidatingScratchpad)
         assert x.tag.something_else == "5"
