@@ -13,12 +13,13 @@
 #   limitations under the License.
 import warnings
 
-import aesara
 import numpy as np
+import pytensor
+import pytensor.tensor as at
 import pytest
 
-from aesara.compile.sharedvalue import SharedVariable
-from aesara.tensor.var import TensorConstant
+from pytensor.compile.sharedvalue import SharedVariable
+from pytensor.tensor.var import TensorConstant
 
 import pymc as pm
 
@@ -101,7 +102,7 @@ def radon_model():
         sigma_y = pm.Uniform("sigma_y", lower=0, upper=100)
 
         # Anonymous SharedVariables don't show up
-        floor_measure = aesara.shared(floor_measure)
+        floor_measure = pytensor.shared(floor_measure)
         floor_measure_offset = pm.MutableData("floor_measure_offset", 1)
         y_hat = a + b * floor_measure + floor_measure_offset
         log_radon = pm.MutableData("log_radon", np.random.normal(1, 1, size=n_homes))
@@ -118,7 +119,7 @@ def radon_model():
         "sigma_y": set(),
         "y_like": {"a", "b", "sigma_y", "floor_measure_offset"},
         "floor_measure_offset": set(),
-        # observed data don't have parents in the model graph, but are shown as decendants
+        # observed data don't have parents in the model graph, but are shown as descendants
         # of the model variables that the observations belong to:
         "log_radon": {"y_like"},
     }
@@ -276,7 +277,7 @@ class BaseModelGraphTest(SeededTest):
             parents_in_graph = self.model_graph.get_parent_names(var)
             if isinstance(var, (SharedVariable, TensorConstant)):
                 # observed data also doesn't have parents in the compute graph!
-                # But for the visualization we like them to become decendants of the
+                # But for the visualization we like them to become descendants of the
                 # RVs that these observations belong to.
                 assert not parents_in_graph
             else:
@@ -340,6 +341,18 @@ class TestImputationModel(BaseModelGraphTest):
 class TestModelWithDims(BaseModelGraphTest):
     model_func = model_with_dims
 
+    def test_issue_6335_dims_containing_none(self):
+        with pm.Model(coords=dict(time=np.arange(5))) as pmodel:
+            data = at.as_tensor(np.ones((3, 5)))
+            pm.Deterministic("n", data, dims=(None, "time"))
+
+        mg = ModelGraph(pmodel)
+        plates_actual = mg.get_plates()
+        plates_expected = {
+            "n_dim0 (3) x time (5)": {"n"},
+        }
+        assert plates_actual == plates_expected
+
 
 class TestUnnamedObservedNodes(BaseModelGraphTest):
     model_func = model_unnamed_observed_node
@@ -394,3 +407,18 @@ class TestVariableSelection:
 
 class TestModelNonRandomVariableRVs(BaseModelGraphTest):
     model_func = model_non_random_variable_rvs
+
+
+def test_model_graph_with_intermediate_named_variables():
+    # Issue 6421
+    with pm.Model() as m1:
+        a = pm.Normal("a", 0, 1, shape=3)
+        pm.Normal("b", a.mean(axis=-1), 1)
+    assert dict(ModelGraph(m1).make_compute_graph()) == {"a": set(), "b": {"a"}}
+
+    with pm.Model() as m2:
+        a = pm.Normal("a", 0, 1)
+        b = a + 1
+        b.name = "b"
+        pm.Normal("c", b, 1)
+    assert dict(ModelGraph(m2).make_compute_graph()) == {"a": set(), "c": {"a"}}
