@@ -22,12 +22,12 @@ import warnings
 
 from typing import Optional, Sequence
 
-import aesara.gradient as tg
 import numpy as np
+import pytensor.gradient as tg
 
-from aesara import Variable
 from fastprogress.fastprogress import ProgressBar, progress_bar
 from numpy import isfinite
+from pytensor import Variable
 from scipy.optimize import minimize
 
 import pymc as pm
@@ -103,7 +103,7 @@ def find_MAP(
         try:
             vars = get_value_vars_from_user_vars(vars, model)
         except ValueError as exc:
-            # Accomodate case where user passed non-pure RV nodes
+            # Accommodate case where user passed non-pure RV nodes
             vars = pm.inputvars(model.replace_rvs_by_values(vars))
             if vars:
                 warnings.warn(
