@@ -22,10 +22,10 @@ import cloudpickle
 import numpy as np
 import xarray
 
-from aesara import Variable
-from aesara.compile import SharedVariable
-from aesara.graph.utils import ValidatingScratchpad
 from cachetools import LRUCache, cachedmethod
+from pytensor import Variable
+from pytensor.compile import SharedVariable
+from pytensor.graph.utils import ValidatingScratchpad
 
 
 class _UnsetType:
@@ -235,7 +235,7 @@ def biwrap(wrapper):
 
 
 def dataset_to_point_list(
-    ds: xarray.Dataset, sample_dims: List
+    ds: xarray.Dataset, sample_dims: Sequence[str]
 ) -> Tuple[List[Dict[str, np.ndarray]], Dict[str, Any]]:
     # All keys of the dataset must be a str
     var_names = list(ds.keys())
@@ -380,7 +380,7 @@ def check_dist_not_registered(dist, model=None):
 
 
 def point_wrapper(core_function):
-    """Wrap an aesara compiled function to be able to ingest point dictionaries whilst
+    """Wrap an pytensor compiled function to be able to ingest point dictionaries whilst
     ignoring the keys that are not valid inputs to the core function.
     """
     ins = [i.name for i in core_function.maker.fgraph.inputs if not isinstance(i, SharedVariable)]
@@ -449,7 +449,7 @@ def _get_seeds_per_chain(
 def get_value_vars_from_user_vars(
     vars: Union[Variable, Sequence[Variable]], model
 ) -> List[Variable]:
-    """This function converts user "vars" input into value variables
+    """Converts user "vars" input into value variables.
 
     More often than not, users will pass random variables, and we will extract the
     respective value variables, but we also allow for the input to already be value
